SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0;
SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0;
SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='TRADITIONAL,ALLOW_INVALID_DATES';

DROP SCHEMA IF EXISTS `nccs` ;
CREATE SCHEMA IF NOT EXISTS `nccs` DEFAULT CHARACTER SET utf8 ;
USE `nccs` ;

-- -----------------------------------------------------
-- Table `nccs`.`AlternateDate`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`AlternateDate` ;

CREATE TABLE IF NOT EXISTS `nccs`.`AlternateDate` (
  `SpecialDate` DATE NOT NULL,
  `AlteredScheduleDay` TINYINT(4) NULL DEFAULT NULL,
  PRIMARY KEY (`SpecialDate`))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`BaseInfo`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`BaseInfo` ;

CREATE TABLE IF NOT EXISTS `nccs`.`BaseInfo` (
  `InfomationID` INT NOT NULL DEFAULT '0' COMMENT '0~0x04 : air condition command description;\n0x80: User name;\n0x100: MediaFile auto_increasement value;' /* comment truncated */ /*0x200: Version;*/,
  `Description` VARCHAR(128) NULL DEFAULT NULL,
  `InfoValue` INT NULL DEFAULT NULL,
  PRIMARY KEY (`InfomationID`))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`BroadcastMode`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`BroadcastMode` ;

CREATE TABLE IF NOT EXISTS `nccs`.`BroadcastMode` (
  `idBroadcastMode` INT(11) NOT NULL AUTO_INCREMENT,
  `ModeName` VARCHAR(50) NULL DEFAULT NULL,
  `Priority` INT(11) NOT NULL DEFAULT '10',
  `Enabled` TINYINT(1) NULL DEFAULT '0',
  `StartTime` DATETIME NULL DEFAULT NULL,
  `StopTime` DATETIME NULL DEFAULT NULL,
  `TimeStyle` TINYINT(4) NULL DEFAULT '0' COMMENT '0: means for one day\n   the start date and end date is indicated by starttime and stoptime.\n\nother: means the mode should be repeated weekly.\nbit 0: means sunday\nbit1:  monday\nbit2: tuesday\n...',
  `Active` TINYINT(1) NOT NULL DEFAULT '0',
  PRIMARY KEY (`idBroadcastMode`))
ENGINE = InnoDB
AUTO_INCREMENT = 10
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`DevClasses`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`DevClasses` ;

CREATE TABLE IF NOT EXISTS `nccs`.`DevClasses` (
  `ClassID` INT(11) NOT NULL AUTO_INCREMENT,
  `Name` VARCHAR(50) NULL DEFAULT NULL,
  `Parent` INT(11) NULL DEFAULT NULL,
  PRIMARY KEY (`ClassID`),
  INDEX `ClassParent` (`Parent` ASC),
  CONSTRAINT `ClassParent`
    FOREIGN KEY (`Parent`)
    REFERENCES `nccs`.`DevClasses` (`ClassID`)
    ON DELETE SET NULL
    ON UPDATE SET NULL)
ENGINE = InnoDB
AUTO_INCREMENT = 3
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`DeviceList`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`DeviceList` ;

CREATE TABLE IF NOT EXISTS `nccs`.`DeviceList` (
  `DevID` VARCHAR(50) NOT NULL,
  `Dev_Name` VARCHAR(32) NULL DEFAULT NULL,
  `Parent` INT(11) NULL DEFAULT NULL,
  `DisableParentSchedule` TINYINT(4) NULL DEFAULT '0' COMMENT 'Indicate whether disable inheritting schedule setting from parents groups.',
  `Dev_Description` VARBINARY(96) NULL,
  `Dev_Configuration` VARBINARY(1024) NULL,
  PRIMARY KEY (`DevID`),
  UNIQUE INDEX `DevID_UNIQUE` (`DevID` ASC),
  INDEX `DevClass` (`Parent` ASC),
  CONSTRAINT `DevClass`
    FOREIGN KEY (`Parent`)
    REFERENCES `nccs`.`DevClasses` (`ClassID`)
    ON DELETE SET NULL
    ON UPDATE SET NULL)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`BrdModeMember`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`BrdModeMember` ;

CREATE TABLE IF NOT EXISTS `nccs`.`BrdModeMember` (
  `DevIDMode` INT(11) NOT NULL AUTO_INCREMENT,
  `BrdModeID` INT(11) NOT NULL,
  `DeviceID` VARCHAR(50) NOT NULL,
  PRIMARY KEY (`DevIDMode`),
  UNIQUE INDEX `DevIDMode_UNIQUE` (`BrdModeID` ASC, `DeviceID` ASC),
  INDEX `BrdModeID` (`BrdModeID` ASC),
  INDEX `ModeDeviceID` (`DeviceID` ASC),
  CONSTRAINT `BrdModeID`
    FOREIGN KEY (`BrdModeID`)
    REFERENCES `nccs`.`BroadcastMode` (`idBroadcastMode`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `ModeDeviceID`
    FOREIGN KEY (`DeviceID`)
    REFERENCES `nccs`.`DeviceList` (`DevID`))
ENGINE = InnoDB
AUTO_INCREMENT = 33
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`DevCtrlSchedule`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`DevCtrlSchedule` ;

CREATE TABLE IF NOT EXISTS `nccs`.`DevCtrlSchedule` (
  `ScheduleID` INT(10) UNSIGNED NOT NULL AUTO_INCREMENT,
  `DevID` VARCHAR(50) NOT NULL,
  `ActionTime` TIME NOT NULL,
  `Action` INT(11) NULL DEFAULT NULL,
  `WeekDay` TINYINT(4) NOT NULL,
  `State` INT(11) NULL DEFAULT '0',
  `ExtArgs` VARCHAR(256) NULL DEFAULT NULL,
  `Disable` TINYINT(1) NULL DEFAULT '0',
  PRIMARY KEY (`DevID`, `ActionTime`, `WeekDay`),
  UNIQUE INDEX `ScheduleID_UNIQUE` (`ScheduleID` ASC),
  INDEX `DeviD` (`DevID` ASC),
  INDEX `DeviceID` (`DevID` ASC),
  INDEX `DevCtrlDevId` (`DevID` ASC),
  CONSTRAINT `DevCtrlDevId`
    FOREIGN KEY (`DevID`)
    REFERENCES `nccs`.`DeviceList` (`DevID`))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`DeviceDesiredStaus`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`DeviceDesiredStaus` ;

CREATE TABLE IF NOT EXISTS `nccs`.`DeviceDesiredStaus` (
  `DeviceID` VARCHAR(50) NOT NULL,
  `SessionID` SMALLINT(5) UNSIGNED NULL DEFAULT NULL,
  `BrdPort` SMALLINT(6) NULL DEFAULT NULL,
  `BrdMode` INT(11) NULL DEFAULT NULL,
  `SessionValid` TINYINT(1) NULL DEFAULT '1',
  `SessionType` TINYINT(4) NULL DEFAULT NULL,
  `StreamType` TINYINT(4) NULL DEFAULT NULL,
  `ModePriority` INT(11) NULL DEFAULT NULL,
  `SysEnabled` TINYINT(4) NULL DEFAULT NULL,
  `RfDevCtrl` BINARY(16) NULL DEFAULT NULL,
  PRIMARY KEY (`DeviceID`),
  INDEX `DesiredDevicesID` (`DeviceID` ASC),
  INDEX `DesiredSessionID` (`SessionID` ASC))
ENGINE = MEMORY
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`DeviceLog`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`DeviceLog` ;

CREATE TABLE IF NOT EXISTS `nccs`.`DeviceLog` (
  `DevLogID` BIGINT(20) NOT NULL AUTO_INCREMENT,
  `DeviceID` VARCHAR(50) NULL DEFAULT NULL,
  `DateTime` DATETIME NULL DEFAULT NULL,
  `Event` TINYINT(4) NULL DEFAULT NULL COMMENT '1  offline/online\n2  power on/power off\n3  enabled/  disabled\n4  Normal Text Message' /* comment truncated */ /*5 Urgent Text Message*/,
  `State` TINYINT(4) NULL DEFAULT NULL,
  `CtrlUser` INT(11) NULL DEFAULT NULL,
  `MsgContext` VARCHAR(256) NULL DEFAULT NULL,
  PRIMARY KEY (`DevLogID`))
ENGINE = InnoDB
AUTO_INCREMENT = 1581
DEFAULT CHARACTER SET = utf8
COMMENT = 'Devices log';


-- -----------------------------------------------------
-- Table `nccs`.`DeviceStatistic`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`DeviceStatistic` ;

CREATE TABLE IF NOT EXISTS `nccs`.`DeviceStatistic` (
  `DeviceID` VARCHAR(50) NOT NULL,
  `StatisticDay` DATE NOT NULL,
  `PowerConsumed` BINARY(128) NULL DEFAULT NULL,
  `UsedTime` BINARY(128) NULL DEFAULT NULL,
  PRIMARY KEY (`DeviceID`, `StatisticDay`))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`DeviceStatus`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`DeviceStatus` ;

CREATE TABLE IF NOT EXISTS `nccs`.`DeviceStatus` (
  `DeviceID` VARCHAR(50) NOT NULL,
  `DeviceType` TINYINT(4) NULL DEFAULT '0',
  `DeviceStatus` INT(11) NULL DEFAULT '0',
  `IpAddress` VARCHAR(50) NULL DEFAULT NULL,
  `ShouldSessionID` SMALLINT(6) UNSIGNED NULL DEFAULT '0',
  `ActualSessionID` SMALLINT(6) UNSIGNED NULL DEFAULT '0',
  `State_SysPower` TINYINT(4) NULL DEFAULT '0',
  `State_ProjectorStatus` TINYINT(4) NULL DEFAULT '0',
  `State_ProjectorLampStatus` TINYINT(4) NULL DEFAULT '0',
  `State_ExDevice1Status` TINYINT(4) NULL DEFAULT '0',
  `State_ExDevice2Status` TINYINT(4) NULL DEFAULT '0',
  `State_CurrProjectorSrc` TINYINT(4) NULL DEFAULT '0',
  `State_CurrAudio` TINYINT(4) NULL DEFAULT '0',
  `State_CurrAudioVolume` TINYINT(4) NULL DEFAULT '0',
  `State_CurrMicVolume` TINYINT(4) NULL DEFAULT '0',
  `State_FaultStatus` TINYINT(4) NULL DEFAULT '0',
  `State_MicState` TINYINT(4) NULL DEFAULT '0',
  `State_Mute` TINYINT(4) NULL DEFAULT '0',
  `State_CentralUsedTime` INT(11) NULL DEFAULT '0',
  `State_ProjectorUsedTime` INT(11) NULL DEFAULT '0',
  `State_LightUsedTime` INT(11) NULL DEFAULT '0',
  `Cfg_System` TINYINT NULL DEFAULT NULL,
  `Cfg_Remark` VARBINARY(96) NULL DEFAULT NULL,
  `netid` TINYINT(4) NULL DEFAULT '-1',
  `NetworkID` INT(11) NULL DEFAULT '0',
  `BrdPort` INT(11) NULL DEFAULT NULL,
  `RfDevStatus` BINARY(16) NULL DEFAULT NULL,
  PRIMARY KEY (`DeviceID`),
  UNIQUE INDEX `DeviceID_UNIQUE` (`DeviceID` ASC),
  INDEX `DevID` (`DeviceID` ASC),
  INDEX `Device` (`DeviceID` ASC),
  INDEX `DevicestatusNetworkID` (`NetworkID` ASC))
ENGINE = MEMORY
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`Players`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`Players` ;

CREATE TABLE IF NOT EXISTS `nccs`.`Players` (
  `PlayerID` VARCHAR(50) NOT NULL,
  `PlayerName` VARBINARY(32) NULL DEFAULT NULL,
  `PlayerType` TINYINT(4) NULL DEFAULT NULL COMMENT '0: celt audio player\n8: vlc player' /* comment truncated */ /*1: audio play devices*/,
  `Priority` TINYINT(4) NULL DEFAULT '10',
  `Remark` VARBINARY(96) NULL DEFAULT NULL,
  PRIMARY KEY (`PlayerID`),
  UNIQUE INDEX `ID_UNIQUE` (`PlayerID` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`Users`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`Users` ;

CREATE TABLE IF NOT EXISTS `nccs`.`Users` (
  `User_ID` INT(11) NOT NULL AUTO_INCREMENT,
  `User_Name` VARCHAR(255) NULL,
  `User_Desc` VARCHAR(255) NULL,
  `Pass_Word` VARCHAR(256) NULL DEFAULT 'password, encode with PASSWORD()',
  `UsbKey` VARCHAR(50) NULL DEFAULT NULL COMMENT 'when the user\'s authorization is expired.' /* comment truncated */ /*After expired, all authorized devices will be deleted.*/,
  `Priority` INT(11) NULL DEFAULT '100',
  `privilege` INT(11) NOT NULL DEFAULT '0' COMMENT 'Bit 0: privilege of device control.\nBit1~Bit7: Reservered\n\nBit 8: privilege of creating audio and vedio broadcast tasks.\nBit9~Bit15: Reservered\n' /* comment truncated */ /*Bit 16: privilege of air condition control*/,
  `IcCard` VARCHAR(50) NULL,
  PRIMARY KEY (`User_ID`),
  UNIQUE INDEX `UsbKey_UNIQUE` (`UsbKey` ASC),
  UNIQUE INDEX `User_Name_UNIQUE` (`User_Name` ASC),
  UNIQUE INDEX `IcCard_UNIQUE` (`IcCard` ASC),
  CONSTRAINT `UsbKey`
    FOREIGN KEY (`UsbKey`)
    REFERENCES `nccs`.`Players` (`PlayerID`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
AUTO_INCREMENT = 4
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`PlaySessions`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`PlaySessions` ;

CREATE TABLE IF NOT EXISTS `nccs`.`PlaySessions` (
  `SessionID` SMALLINT(6) UNSIGNED NOT NULL DEFAULT '0',
  `SessionName` VARCHAR(50) NOT NULL,
  `SessionType` TINYINT(4) NULL DEFAULT NULL COMMENT '0: automatic broadcast task\n1: player created task\n2: manually played task\n' /* comment truncated */ /*8: auto video session*/,
  `Priority` TINYINT(4) NULL DEFAULT NULL,
  `Status` TINYINT(4) NOT NULL DEFAULT '0',
  `CircleLength` INT(11) NOT NULL DEFAULT '0',
  `ClassID` INT(11) NULL DEFAULT NULL,
  `PlayerID` VARCHAR(50) NULL,
  `Parent` SMALLINT(5) UNSIGNED NULL DEFAULT NULL,
  `BrdMode` INT(11) NULL DEFAULT NULL,
  `MemberMode` TINYINT(1) NOT NULL DEFAULT '0',
  `StreamType` TINYINT(4) NOT NULL DEFAULT '1' COMMENT 'Stream Type: \n1: valid 0: invalid\nBit 0: audio\nBit1: Video',
  `SysEnabled` TINYINT(4) NULL DEFAULT NULL,
  `RfDevCtrl` BINARY(16) NULL DEFAULT NULL,
  `Owner` INT(11) NULL DEFAULT NULL,
  `PlayMode` TINYINT NULL DEFAULT 0 COMMENT '0: Sequential Playing' /* comment truncated */ /*1: Random Playing */,
  `AudioGain` TINYINT NULL DEFAULT 0,
  PRIMARY KEY (`SessionID`),
  UNIQUE INDEX `SessionID_UNIQUE` (`SessionID` ASC),
  INDEX `Players` (`PlayerID` ASC),
  INDEX `SessionParent` (`Parent` ASC),
  INDEX `SessionMode` (`BrdMode` ASC),
  INDEX `SessionUser` (`Owner` ASC),
  CONSTRAINT `Players`
    FOREIGN KEY (`PlayerID`)
    REFERENCES `nccs`.`Players` (`PlayerID`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `SessionMode`
    FOREIGN KEY (`BrdMode`)
    REFERENCES `nccs`.`BroadcastMode` (`idBroadcastMode`),
  CONSTRAINT `SessionParent`
    FOREIGN KEY (`Parent`)
    REFERENCES `nccs`.`PlaySessions` (`SessionID`)
    ON DELETE SET NULL
    ON UPDATE SET NULL,
  CONSTRAINT `SessionUser`
    FOREIGN KEY (`Owner`)
    REFERENCES `nccs`.`Users` (`User_ID`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`PlaySessionTime`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`PlaySessionTime` ;

CREATE TABLE IF NOT EXISTS `nccs`.`PlaySessionTime` (
  `ScheduleID` INT(11) NOT NULL AUTO_INCREMENT,
  `SessionID` SMALLINT(6) UNSIGNED NOT NULL,
  `WeekDay` TINYINT(4) NOT NULL,
  `PlayTime` DATETIME NOT NULL,
  `TempFlag` TINYINT(4) NULL DEFAULT NULL,
  PRIMARY KEY (`ScheduleID`),
  UNIQUE INDEX `SesTime_UNIQUE` (`SessionID` ASC, `WeekDay` ASC, `PlayTime` ASC),
  INDEX `Schsessionid` (`SessionID` ASC),
  CONSTRAINT `Schsessionid`
    FOREIGN KEY (`SessionID`)
    REFERENCES `nccs`.`PlaySessions` (`SessionID`))
ENGINE = InnoDB
AUTO_INCREMENT = 6638
DEFAULT CHARACTER SET = utf8
COMMENT = 'Auto broadcast playing schedules';


-- -----------------------------------------------------
-- Table `nccs`.`DisableDevSession`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`DisableDevSession` ;

CREATE TABLE IF NOT EXISTS `nccs`.`DisableDevSession` (
  `ScheduleID` INT(11) NOT NULL,
  `DeviceID` VARCHAR(50) NOT NULL,
  `Disabled` TINYINT(4) NULL DEFAULT NULL,
  PRIMARY KEY (`ScheduleID`, `DeviceID`),
  INDEX `DisDevShedule` (`ScheduleID` ASC),
  INDEX `DisabledScheDevice` (`DeviceID` ASC),
  CONSTRAINT `DisabledScheDevice`
    FOREIGN KEY (`DeviceID`)
    REFERENCES `nccs`.`DeviceList` (`DevID`),
  CONSTRAINT `DisDevShedule`
    FOREIGN KEY (`ScheduleID`)
    REFERENCES `nccs`.`PlaySessionTime` (`ScheduleID`))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`GroupCtrlSchedule`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`GroupCtrlSchedule` ;

CREATE TABLE IF NOT EXISTS `nccs`.`GroupCtrlSchedule` (
  `ScheduleID` INT(10) UNSIGNED NOT NULL AUTO_INCREMENT,
  `GroupID` INT(11) NOT NULL,
  `ActionTime` TIME NOT NULL,
  `Action` INT(11) NULL DEFAULT NULL,
  `WeekDay` TINYINT(4) NOT NULL,
  `State` INT(11) NULL DEFAULT '0',
  `ExtArgs` VARCHAR(256) NULL DEFAULT NULL,
  `Disable` TINYINT(1) NULL DEFAULT '0',
  PRIMARY KEY (`GroupID`, `ActionTime`, `WeekDay`),
  UNIQUE INDEX `ScheduleID_UNIQUE` (`ScheduleID` ASC),
  INDEX `DeviD` (`GroupID` ASC),
  INDEX `DeviceID` (`GroupID` ASC),
  INDEX `DevCtrlGroupID` (`GroupID` ASC),
  CONSTRAINT `DevCtrlGroupID`
    FOREIGN KEY (`GroupID`)
    REFERENCES `nccs`.`DevClasses` (`ClassID`))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`LastProcessedTime`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`LastProcessedTime` ;

CREATE TABLE IF NOT EXISTS `nccs`.`LastProcessedTime` (
  `LastTimeID` INT(11) NOT NULL DEFAULT '1' COMMENT 'Only one record in this table',
  `LastTime` DATETIME NULL DEFAULT NULL,
  PRIMARY KEY (`LastTimeID`))
ENGINE = MEMORY
DEFAULT CHARACTER SET = utf8
COMMENT = 'a globe time which record last timer process time.';


-- -----------------------------------------------------
-- Table `nccs`.`MediaFiles`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`MediaFiles` ;

CREATE TABLE IF NOT EXISTS `nccs`.`MediaFiles` (
  `MediaID` INT(11) NOT NULL AUTO_INCREMENT,
  `FileName` VARCHAR(64) NULL,
  `FileSize` BIGINT NULL,
  `TotalTime` INT(11) NOT NULL DEFAULT '0',
  `FileFmt` INT(11) NULL COMMENT '0: celt\n1: mp3\n2: ts\n3: mp4, mov' /* comment truncated */ /*4: avi*/,
  `BitRate` INT(11) NULL DEFAULT NULL,
  `VedioCodec` INT(11) NULL DEFAULT NULL COMMENT '0: h264\n1: mpeg4',
  `Height` INT(11) NULL,
  `Width` INT(11) NULL DEFAULT NULL,
  `FrameRate` INT(11) NULL,
  `AudioCodec` INT(11) NULL DEFAULT NULL COMMENT '0: celt\n1: mp3' /* comment truncated */ /*2: aac*/,
  `Channels` INT(11) NULL DEFAULT NULL,
  `SampleRate` INT(11) NULL DEFAULT NULL,
  `Parent` INT(11) NULL DEFAULT NULL,
  `Gain` TINYINT(4) NULL DEFAULT '0',
  `CreateTime` DATETIME NULL,
  `FilePath` VARCHAR(256) NULL,
  `Owner` INT(11) NULL COMMENT 'sysfolder owner',
  `Sysfolder` TINYINT(4) NULL DEFAULT NULL COMMENT 'system create folder,not update or delete\n1:true' /* comment truncated */ /*0,null:false*/,
  PRIMARY KEY (`MediaID`),
  UNIQUE INDEX `ID_UNIQUE` (`MediaID` ASC),
  INDEX `MediaParent` (`Parent` ASC),
  INDEX `MediaUser_idx` (`Owner` ASC),
  CONSTRAINT `MediaParent`
    FOREIGN KEY (`Parent`)
    REFERENCES `nccs`.`MediaFiles` (`MediaID`)
    ON DELETE SET NULL
    ON UPDATE SET NULL,
  CONSTRAINT `MediaUser`
    FOREIGN KEY (`Owner`)
    REFERENCES `nccs`.`Users` (`User_ID`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
AUTO_INCREMENT = 57
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`Messages`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`Messages` ;

CREATE TABLE IF NOT EXISTS `nccs`.`Messages` (
  `ID` INT(11) NOT NULL AUTO_INCREMENT,
  `MsgFrom` TINYINT(4) NOT NULL,
  `MsgTo` TINYINT(4) NOT NULL,
  `MsgType` TINYINT(4) NULL DEFAULT NULL,
  `MsgTime` DATETIME NULL DEFAULT NULL,
  `CmdType` INT(11) NULL DEFAULT NULL,
  `CmdObjType` INT(11) NULL DEFAULT NULL,
  `CmdObjID` VARCHAR(50) NULL DEFAULT NULL,
  `CmdObjIP` VARCHAR(50) NULL DEFAULT NULL,
  PRIMARY KEY (`ID`),
  UNIQUE INDEX `ID_UNIQUE` (`ID` ASC))
ENGINE = MEMORY
AUTO_INCREMENT = 782
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`MsgTasks`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`MsgTasks` ;

CREATE TABLE IF NOT EXISTS `nccs`.`MsgTasks` (
  `MsgTaskID` INT(11) NOT NULL,
  `PlayedTime` DATETIME NULL DEFAULT NULL,
  `TimeStyle` INT(11) NULL DEFAULT NULL COMMENT '0: Play one time.\n    played on PlayedTime.\nother: repeat weekly' /* comment truncated */ /*    bit0~bit7: from monday to sunday.*/,
  `Duration` INT(11) NULL DEFAULT NULL,
  `Content` VARCHAR(256) NULL DEFAULT NULL,
  PRIMARY KEY (`MsgTaskID`))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`MsgTaskDev`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`MsgTaskDev` ;

CREATE TABLE IF NOT EXISTS `nccs`.`MsgTaskDev` (
  `MsgTaskID` INT(11) NOT NULL,
  `DevID` VARCHAR(45) NOT NULL,
  PRIMARY KEY (`MsgTaskID`, `DevID`),
  INDEX `msgtask` (`MsgTaskID` ASC),
  INDEX `msgtaskdev` (`DevID` ASC),
  CONSTRAINT `msgtask`
    FOREIGN KEY (`MsgTaskID`)
    REFERENCES `nccs`.`MsgTasks` (`MsgTaskID`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `msgtaskdev`
    FOREIGN KEY (`DevID`)
    REFERENCES `nccs`.`DeviceList` (`DevID`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`PlayListFiles`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`PlayListFiles` ;

CREATE TABLE IF NOT EXISTS `nccs`.`PlayListFiles` (
  `PlayListFIleId` INT(11) NOT NULL AUTO_INCREMENT,
  `FileID` INT(11) NULL DEFAULT NULL,
  `SequenceID` INT(11) NOT NULL,
  `SessionID` SMALLINT(6) UNSIGNED NOT NULL,
  `Duration` INT(11) NULL DEFAULT '0',
  `KeyIndex` INT(11) NULL DEFAULT NULL,
  `PlayerID` VARCHAR(50) NULL DEFAULT NULL,
  PRIMARY KEY (`PlayListFIleId`),
  UNIQUE INDEX `SessionIDSeq` (`SessionID` ASC, `SequenceID` ASC),
  INDEX `SessionID` (`SessionID` ASC),
  INDEX `FileID` (`FileID` ASC),
  CONSTRAINT `FileID`
    FOREIGN KEY (`FileID`)
    REFERENCES `nccs`.`MediaFiles` (`MediaID`),
  CONSTRAINT `SessionID`
    FOREIGN KEY (`SessionID`)
    REFERENCES `nccs`.`PlaySessions` (`SessionID`))
ENGINE = InnoDB
AUTO_INCREMENT = 62
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`PlayerAlive`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`PlayerAlive` ;

CREATE TABLE IF NOT EXISTS `nccs`.`PlayerAlive` (
  `PlayerID` VARCHAR(50) NOT NULL,
  `RefreshTime` DATETIME NULL DEFAULT NULL,
  PRIMARY KEY (`PlayerID`),
  INDEX `PlayerActivePlayerID` (`PlayerID` ASC))
ENGINE = MEMORY
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`PlayerKeys`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`PlayerKeys` ;

CREATE TABLE IF NOT EXISTS `nccs`.`PlayerKeys` (
  `PlayerKeyId` INT(11) NOT NULL AUTO_INCREMENT,
  `PlayerID` VARCHAR(50) NOT NULL,
  `Index` INT(11) NOT NULL,
  `GroupDisable` TINYINT(4) NULL DEFAULT '0',
  `DevDisable` TINYINT(4) NULL DEFAULT '0',
  `GroupID` INT(11) NULL DEFAULT NULL,
  PRIMARY KEY (`PlayerKeyId`),
  UNIQUE INDEX `PlayerIndex` (`PlayerID` ASC, `Index` ASC),
  INDEX `PlayerKey_PlayerID` (`PlayerID` ASC),
  INDEX `PlayerGroupID` (`GroupID` ASC),
  CONSTRAINT `PlayerGroupID`
    FOREIGN KEY (`GroupID`)
    REFERENCES `nccs`.`DevClasses` (`ClassID`)
    ON DELETE SET NULL
    ON UPDATE SET NULL,
  CONSTRAINT `PlayerKey_PlayerID`
    FOREIGN KEY (`PlayerID`)
    REFERENCES `nccs`.`Players` (`PlayerID`))
ENGINE = InnoDB
AUTO_INCREMENT = 491361
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`PlayerStatus`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`PlayerStatus` ;

CREATE TABLE IF NOT EXISTS `nccs`.`PlayerStatus` (
  `PlayerID` VARCHAR(50) NOT NULL,
  `SessionID` SMALLINT(5) UNSIGNED NULL DEFAULT '0',
  `ScheduleID` INT(11) NULL DEFAULT NULL,
  `IpAddress` VARCHAR(50) NULL DEFAULT NULL,
  `NetID` TINYINT(4) NULL DEFAULT NULL,
  `ActualSesID` INT(11) NULL DEFAULT NULL,
  `PlayPort` INT(11) NULL DEFAULT NULL,
  `PlayType` TINYINT(4) NULL DEFAULT NULL,
  PRIMARY KEY (`PlayerID`),
  INDEX `PlayerStatusPlayerID` (`PlayerID` ASC),
  INDEX `PlayerStatusSessionID` (`SessionID` ASC),
  INDEX `PlayerStatusScheduleID` (`ScheduleID` ASC))
ENGINE = MEMORY
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`PlayingSessions`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`PlayingSessions` ;

CREATE TABLE IF NOT EXISTS `nccs`.`PlayingSessions` (
  `SessionID` SMALLINT(6) UNSIGNED NOT NULL,
  `PlayerID` VARCHAR(50) NULL DEFAULT NULL,
  `PlayingFileID` INT(11) NULL DEFAULT NULL,
  `MultiPort` INT(11) NULL DEFAULT NULL,
  `CircleLength` INT(11) NULL DEFAULT NULL,
  `CurrFileProgress` INT(11) NULL DEFAULT NULL,
  `CurrTotalProgress` INT(11) NULL DEFAULT NULL,
  `Priority` TINYINT(4) NULL DEFAULT NULL,
  `Pause` TINYINT(4) NOT NULL DEFAULT '0',
  `ScheduleID` INT(11) NULL DEFAULT NULL,
  `BrdMode` INT(11) NULL DEFAULT NULL,
  `SesType` TINYINT(4) NULL DEFAULT '0',
  `StreamType` TINYINT(4) NULL DEFAULT '1',
  PRIMARY KEY (`SessionID`),
  UNIQUE INDEX `SessionID_UNIQUE` (`SessionID` ASC),
  UNIQUE INDEX `PlayerID_UNIQUE` (`PlayerID` ASC),
  INDEX `Session` (`SessionID` ASC))
ENGINE = MEMORY
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`ProjectorType`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`ProjectorType` ;

CREATE TABLE IF NOT EXISTS `nccs`.`ProjectorType` (
  `Type` VARCHAR(50) NOT NULL,
  `PoweroffDelay` INT(11) NOT NULL,
  `CheckBit` INT(11) NOT NULL,
  `StopBit` INT(11) NOT NULL,
  `DataBit` INT(11) NOT NULL,
  `BaudRate` INT(11) NOT NULL,
  `CmdOpen` VARCHAR(255) NOT NULL,
  `CmdClose` VARCHAR(255) NOT NULL,
  `CmdFromPc` VARCHAR(255) NOT NULL,
  `CmdFromVideo` VARCHAR(255) NOT NULL,
  PRIMARY KEY (`Type`),
  UNIQUE INDEX `Type_UNIQUE` (`Type` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`SessionDevice`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`SessionDevice` ;

CREATE TABLE IF NOT EXISTS `nccs`.`SessionDevice` (
  `SessionDevID` INT(11) NOT NULL AUTO_INCREMENT,
  `DeviceID` VARCHAR(50) NOT NULL,
  `SessionID` SMALLINT(5) UNSIGNED NOT NULL,
  `KeyIndex` INT(11) NOT NULL DEFAULT '0',
  `DevDisabled` TINYINT(4) NULL DEFAULT '0',
  PRIMARY KEY (`SessionDevID`),
  UNIQUE INDEX `SessionDevKey` (`SessionID` ASC, `DeviceID` ASC, `KeyIndex` ASC),
  INDEX `SessionDevDev` (`DeviceID` ASC),
  INDEX `SessionDevSes` (`SessionID` ASC),
  CONSTRAINT `SessionDevDev`
    FOREIGN KEY (`DeviceID`)
    REFERENCES `nccs`.`DeviceList` (`DevID`),
  CONSTRAINT `SessionDevSes`
    FOREIGN KEY (`SessionID`)
    REFERENCES `nccs`.`PlaySessions` (`SessionID`))
ENGINE = InnoDB
AUTO_INCREMENT = 334
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`SubNetwork`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`SubNetwork` ;

CREATE TABLE IF NOT EXISTS `nccs`.`SubNetwork` (
  `idSubNetwork` INT(11) NOT NULL,
  `NetMask` VARCHAR(50) NULL DEFAULT NULL,
  `IpAddress` VARCHAR(50) NULL DEFAULT NULL,
  PRIMARY KEY (`idSubNetwork`),
  UNIQUE INDEX `idSubNetwork_UNIQUE` (`idSubNetwork` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`UserDevices`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`UserDevices` ;

CREATE TABLE IF NOT EXISTS `nccs`.`UserDevices` (
  `UserDevID` INT(11) NOT NULL AUTO_INCREMENT,
  `UserID` INT(11) NOT NULL,
  `DevID` VARCHAR(50) NOT NULL,
  PRIMARY KEY (`UserDevID`),
  UNIQUE INDEX `UserDev` (`UserID` ASC, `DevID` ASC),
  INDEX `user_dev` (`DevID` ASC),
  INDEX `UserId` (`UserID` ASC),
  CONSTRAINT `UserId`
    FOREIGN KEY (`UserID`)
    REFERENCES `nccs`.`Users` (`User_ID`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `user_dev`
    FOREIGN KEY (`DevID`)
    REFERENCES `nccs`.`DeviceList` (`DevID`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
AUTO_INCREMENT = 9
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`tmp_result`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`tmp_result` ;

CREATE TABLE IF NOT EXISTS `nccs`.`tmp_result` (
  `idtmp_result` INT(11) NULL DEFAULT NULL)
ENGINE = MEMORY
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`TempIcCard`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`TempIcCard` ;

CREATE TABLE IF NOT EXISTS `nccs`.`TempIcCard` (
  `UserID` INT NOT NULL,
  `DeviceID` VARCHAR(50) NOT NULL,
  `RecordTime` TIMESTAMP NOT NULL)
ENGINE = MEMORY;


-- -----------------------------------------------------
-- Table `nccs`.`tmp_DelMediaFiles`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`tmp_DelMediaFiles` ;

CREATE TABLE IF NOT EXISTS `nccs`.`tmp_DelMediaFiles` (
  `filepath` VARCHAR(256) NOT NULL,
  PRIMARY KEY (`filepath`))
ENGINE = MEMORY
DEFAULT CHARACTER SET = utf8;

USE `nccs` ;

-- -----------------------------------------------------
-- Placeholder table for view `nccs`.`v_DeviceModes`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `nccs`.`v_DeviceModes` (`DeviceID` INT, `BrdModeID` INT, `Priority` INT);

-- -----------------------------------------------------
-- Placeholder table for view `nccs`.`v_Session_Files`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `nccs`.`v_Session_Files` (`SessionID` INT, `FileID` INT, `SequenceID` INT, `FileName` INT, `TotalTime` INT, `PlayTime` INT, `Gain` INT, `FileFmt` INT, `FilePath` INT);

-- -----------------------------------------------------
-- Placeholder table for view `nccs`.`v_active_mode_members`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `nccs`.`v_active_mode_members` (`DeviceID` INT, `BrdModeID` INT, `Priority` INT);

-- -----------------------------------------------------
-- Placeholder table for view `nccs`.`v_session_info`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `nccs`.`v_session_info` (`SessionID` INT, `SessionName` INT, `SessionType` INT, `Priority` INT, `Status` INT, `CircleLength` INT, `ClassID` INT, `PlayerID` INT, `Parent` INT, `PlayingFileID` INT, `MultiPort` INT, `CurrFileProgress` INT, `CurrTotalProgress` INT, `Pause` INT, `ScheduleID` INT, `MemberMode` INT);

-- -----------------------------------------------------
-- Placeholder table for view `nccs`.`v_session_schedules`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `nccs`.`v_session_schedules` (`ScheduleID` INT, `TempFlag` INT, `PlayTime` INT, `WeekDay` INT, `SessionID` INT, `SessionName` INT, `Pause` INT, `BrdMode` INT, `SessionType` INT, `SysEnabled` INT, `RfDevCtrl` INT, `StreamType` INT);

-- -----------------------------------------------------
-- Placeholder table for view `nccs`.`v_stream_trans_table`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `nccs`.`v_stream_trans_table` (`NetworkID` INT, `proxy` INT, `IpAddress` INT, `MultiPort` INT, `SessionID` INT);

-- -----------------------------------------------------
-- procedure delete_task
-- -----------------------------------------------------

USE `nccs`;
DROP procedure IF EXISTS `nccs`.`delete_task`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` PROCEDURE `delete_task`(taskid int)
begin
declare ses_id smallint default null;
select  SessionID into ses_id from PlaySessionTime where ScheduleID = taskid;

if (ses_id is not null) then
    call sp_session_ctrl(ses_id, 0, taskid);
end if;

Delete from PlaySessionTime where ScheduleID = taskid;

end$$

DELIMITER ;

-- -----------------------------------------------------
-- function func_check_dev_stream
-- -----------------------------------------------------

USE `nccs`;
DROP function IF EXISTS `nccs`.`func_check_dev_stream`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` FUNCTION `func_check_dev_stream`( 
                                    dev_id varchar(50),
                                    stream_type int) RETURNS tinyint(1)
begin

if (ASCII(dev_id) = 0x30) then
     return false;
end if;    

if ((stream_type & 0x02)  <> 0) then
    if (ASCII(right(dev_id, 9)) <> 0x38) then
         return false;
     end if;    
end if;

return true;
end$$

DELIMITER ;

-- -----------------------------------------------------
-- function func_check_mode_daytime
-- -----------------------------------------------------

USE `nccs`;
DROP function IF EXISTS `nccs`.`func_check_mode_daytime`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` FUNCTION `func_check_mode_daytime`( 
          weekday tinyint, 
          checked_time datetime,
          last_time datetime,
          cur_time datetime
         ) RETURNS tinyint(1)
begin
declare cur_weekday tinyint default null;
declare checked_date date;

-- check whether time is matched
if (last_time >= cur_time) then
    return false;
end if;    

-- time is matched, check date
if  (weekday = 0) then
-- compare special day
    if (checked_time  > last_time) and (checked_time <= cur_time) then 
        return true;
    end if;    
else
    -- for repeated weekly
     if (time(last_time) > time(cur_time)) then
         -- current date change to next day
         if (time(checked_time) > time(last_time) ) then
              set checked_date = date(last_time);
         else 
              if (time(checked_time) <= time(cur_time)) then
                    set checked_date = date(cur_time);
              else
                    return false;
               end if ;    
          end if;
      else
          -- current date is same as last date
          if (time(checked_time) <= time(last_time) )  or 
              (time(checked_time) > time(cur_time))  then
              -- time is not mached
              return false;
           end if;   
           
           set checked_date = date(cur_time);
      end if;
      
       -- Get alternated week          
      select AlteredScheduleDay into cur_weekday from AlternateDate where SpecialDate = checked_date;

      if cur_weekday is null then 
           set cur_weekday = weekday(checked_date);
       end if;
     
    if (weekday & (0x01 << cur_weekday)  <> 0 ) then 
        -- date is matched
        return true;
   end if;    
end if;

return false;
end$$

DELIMITER ;

-- -----------------------------------------------------
-- function func_check_mode_enabled
-- -----------------------------------------------------

USE `nccs`;
DROP function IF EXISTS `nccs`.`func_check_mode_enabled`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` FUNCTION `func_check_mode_enabled`( modeid int , 
      PlayTime time,
      PlayDate date) RETURNS tinyint(1)
begin
declare cur_weekday tinyint default null;
declare checked_date date;
declare modeactive boolean default false;
declare modeenable boolean default false;
declare modestarttime datetime  default null;
declare modestoptime datetime  default null;
declare modetimestype tinyint default null;
declare matched boolean default false;

select Active, Enabled, StartTime, StopTime,TimeStyle into modeactive, modeenable, modestarttime, modestoptime, modetimestype 
            from BroadcastMode where idBroadcastMode = modeid limit 1;
   
  if (modeenable = false) then
     return false;
  end if;   
 -- check day matched        
 if (modetimestype = 0) then
     if (PlayDate = date(modestarttime) ) then
         set matched = true;
      end if;
 else
     select AlteredScheduleDay into cur_weekday from AlternateDate where SpecialDate = PlayDate;
      if cur_weekday is null then 
           set cur_weekday = weekday(PlayDate);
       end if;       
       if (modetimestype & (0x01 << cur_weekday)  <> 0 ) then 
        -- date is matched
        set matched = true;
        end if;
   end if;    
    
if (matched = false) then 
    -- mode state will not change in today
    if  (modeactive = false) then
        return false;
    end if;
 end if;
 
 if  (modeactive = false)  and (PlayTime < time(modestarttime)) then
     return false;
 end if;    

if (PlayTime <  time(modestoptime)) then
    return true;
end if;    
return false;
end$$

DELIMITER ;

-- -----------------------------------------------------
-- function func_check_session_daytime
-- -----------------------------------------------------

USE `nccs`;
DROP function IF EXISTS `nccs`.`func_check_session_daytime`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` FUNCTION `func_check_session_daytime`(
          brdmode int,
          weekday tinyint, 
          checked_time datetime,
          last_time datetime,
          cur_time datetime
         ) RETURNS tinyint(1)
begin

declare cur_weekday tinyint default null;
declare checked_date date;
declare activemode boolean default false;

-- check whether time is matched
if (last_time >= cur_time) then
    return false;
end if;    

if (brdmode > 0) then
     select Active into activemode from BroadcastMode where idBroadcastMode = brdmode limit 1;
     if  not (activemode = true) then
        return false;
     end if;
end if;     

-- time is matched, check date
if  (weekday > 6) then
-- compare special day
    if (checked_time  > last_time) and (checked_time <= cur_time) then 
        return true;
    end if;    
else
    -- for repeated weekly
     if (time(last_time) > time(cur_time)) then
         -- current date change to next day
         if (time(checked_time) > time(last_time) ) then
              set checked_date = date(last_time);
         else 
              if (time(checked_time) <= time(cur_time)) then
                    set checked_date = date(cur_time);
              else
                    return false;
               end if ;    
          end if;
      else
          -- current date is same as last date
          if (time(checked_time) <= time(last_time) )  or 
              (time(checked_time) > time(cur_time))  then
              -- time is not mached
              return false;
           end if;   
           
           set checked_date = date(cur_time);
      end if;
      
       -- Get alternated week          
      select AlteredScheduleDay into cur_weekday from AlternateDate where SpecialDate = checked_date;

      if cur_weekday is null then 
           set cur_weekday = weekday(checked_date);
       end if;
     
    if (brdmode > 0) or (weekday = cur_weekday)  then 
        -- date is matched
        return true;
   end if;    
end if;

return false;
end$$

DELIMITER ;

-- -----------------------------------------------------
-- function func_get_dev_mode
-- -----------------------------------------------------

USE `nccs`;
DROP function IF EXISTS `nccs`.`func_get_dev_mode`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` FUNCTION `func_get_dev_mode`( 
                                    dev_id varchar(50),
                                    checked_daytime datetime) RETURNS int(11)
begin
   declare checkday date;
   declare checktime time;
   declare checkweek int;
   declare ret int default null;
   
   set checkday = date(checked_daytime);
   set checktime = time(checked_daytime);
   
   select AlteredScheduleDay into checkweek from AlternateDate where SpecialDate = checkday;
    if checkweek is null then 
           set checkweek = weekday(checkday);
    end if;       

   
   select  BroadcastMode.idBroadcastMode into ret from BroadcastMode, BrdModeMember 
                  where (BrdModeMember.DeviceID =  dev_id) and
                                 (BrdModeMember.BrdModeID = BroadcastMode.idBroadcastMode) and
                                 (BroadcastMode.Enabled = true) and
                                       ((BroadcastMode.TimeStyle = 0 and checkday = date(BroadcastMode.StartTime) ) or
                                       (BroadcastMode.TimeStyle & (0x01 << checkweek)  <> 0))  and
                                 (checktime >= time(BroadcastMode.StartTime) and checktime < time(BroadcastMode.StopTime) )
  order by BroadcastMode.Priority limit 1;
  
  return ret;
end$$

DELIMITER ;

-- -----------------------------------------------------
-- function func_keepalive_transmit
-- -----------------------------------------------------

USE `nccs`;
DROP function IF EXISTS `nccs`.`func_keepalive_transmit`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`localhost` FUNCTION `func_keepalive_transmit`( 
          net_id int, proxy varchar(50),dst_ip varchar(50)
         ) RETURNS varchar(50) CHARSET gb2312
begin
if  (dst_ip is null)  and (proxy = '0.0.0.0') then
    return 0;
end if;    

if (net_id = 0)  then     
    return srv_send_keepalive(proxy, 7805, 32) ;
 else 
    if  (dst_ip is null)  then
        return srv_send_keepalive(proxy, 7805, 40) ;          
     else    
        return srv_send_keepalive(dst_ip, 7805, 40) ;
     end if;    
end if;

end$$

DELIMITER ;

-- -----------------------------------------------------
-- function get_dev_mode
-- -----------------------------------------------------

USE `nccs`;
DROP function IF EXISTS `nccs`.`get_dev_mode`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` FUNCTION `get_dev_mode`(dev_id varchar(50)) RETURNS int(11)
begin
 declare ret int default 0;
 
 select BrdModeMember.BrdModeID into ret from BrdModeMember
                left join BroadcastMode on BroadcastMode.idBroadcastMode = BrdModeMember.BrdModeID
                where (BrdModeMember.DeviceID = dev_id) and (BroadcastMode.Active = true) 
                 order by    BroadcastMode. Priority LIMIT 1;       
                 
 return ret;                
end$$

DELIMITER ;

-- -----------------------------------------------------
-- function get_dev_session
-- -----------------------------------------------------

USE `nccs`;
DROP function IF EXISTS `nccs`.`get_dev_session`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` FUNCTION `get_dev_session`(dev_id varchar(50), sessionId smallint unsigned, 
                                                                                       playerid varchar(50), SesMode int) RETURNS tinyint(1)
begin
 declare modeid int default 0;
 declare sespriority int default null;
 declare modepriority int default null;
 declare modemembertype boolean default false;
 
 set modeid = get_dev_mode(dev_id) ;
 
 select Priority into modepriority from BroadcastMode where idBroadcastMode = modeid LIMIT 0, 1;
 select Priority , MemberMode into sespriority, modemembertype from
                               PlaySessions where PlaySessions.SessionID = sessionId LIMIT 0, 1;
 
  
 if (modeid = SesMode and  modemembertype = true) then
 -- device in mode, and session is in same mode, and sesstion use mode members
     return true;
  end if;
  
 if not (modeid > 0 and  SesMode <> modeid and sespriority >= modepriority) then
    if exists (select DeviceID from SessionDevice 
                 where (SessionDevice.DeviceID = dev_id) and (SessionDevice.SessionID = sessionId) and (not DevDisabled = 1)) then
                 -- for automatic session or manual session
                 return true;
      else
                return exists (select DeviceList .DevID from DeviceList , PlayerKeys 
                            where DeviceList .DevID =  dev_id and PlayerKeys.PlayerID = playerid and
                            PlayerKeys.GroupDisable = 0 and 
                            ((PlayerKeys.GroupID <> 0) and sp_dev_belong_group(DeviceList.DevID, PlayerKeys.GroupID)));

    end if;  
 end if;

  
  return false;                                
end$$

DELIMITER ;

-- -----------------------------------------------------
-- function get_idle_port
-- -----------------------------------------------------

USE `nccs`;
DROP function IF EXISTS `nccs`.`get_idle_port`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` FUNCTION `get_idle_port`() RETURNS int(10) unsigned
begin

declare idle_port int unsigned;

set idle_port = 7000;

emp_loop: loop   
if not exists(select * from PlayerStatus where PlayPort = idle_port) then   
leave emp_loop;
end if;
set idle_port = idle_port + 2;
end loop;

return  idle_port;
end$$

DELIMITER ;

-- -----------------------------------------------------
-- function get_idle_sessionid
-- -----------------------------------------------------

USE `nccs`;
DROP function IF EXISTS `nccs`.`get_idle_sessionid`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` FUNCTION `get_idle_sessionid`(video boolean) RETURNS smallint(5) unsigned
begin

declare ses_id smallint unsigned default 1;

 emp_loop: loop   
if not exists(select SessionID from PlaySessions where SessionID = ses_id) then   
leave emp_loop;
end if;
set ses_id = ses_id + 1;
end loop;

return  ses_id;
end$$

DELIMITER ;

-- -----------------------------------------------------
-- function get_network
-- -----------------------------------------------------

USE `nccs`;
DROP function IF EXISTS `nccs`.`get_network`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` FUNCTION `get_network`(ipaddr varchar(50)) RETURNS int(10) unsigned
BEGIN

declare src_ip int unsigned;
declare mask int unsigned;
declare proxy int unsigned;
declare netid int unsigned;
declare ret int default 0;

DECLARE done INT DEFAULT 0;   
DECLARE cur1 CURSOR FOR SELECT 
    idSubNetwork, inet_aton(NetMask), inet_aton(IpAddress) 
    FROM SubNetwork;   
DECLARE CONTINUE HANDLER FOR NOT FOUND SET done=1;   

set src_ip = inet_aton(ipaddr);
OPEN cur1;   

emp_loop: LOOP   

FETCH cur1 INTO netid, mask, proxy;   

if ((src_ip & mask) = (proxy & mask))  and (mask <> 0) then
set ret = netid;
set done = 1;
-- else
-- set done = 1;
end if;

IF done=1 THEN   
LEAVE emp_loop;   
END IF;   
END LOOP emp_loop;   
CLOSE cur1;   

return  ret;
END$$

DELIMITER ;

-- -----------------------------------------------------
-- procedure sp_add_media_blcok
-- -----------------------------------------------------

USE `nccs`;
DROP procedure IF EXISTS `nccs`.`sp_add_media_blcok`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` PROCEDURE `sp_add_media_blcok`(in media_id int,
        in dat varbinary(8192),
        out ret int)
BEGIN
         set ret = add_media_block(CONCAT(@@datadir, 'media/', media_id) , dat);                      
END$$

DELIMITER ;

-- -----------------------------------------------------
-- procedure sp_check_group
-- -----------------------------------------------------

USE `nccs`;
DROP procedure IF EXISTS `nccs`.`sp_check_group`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`localhost` PROCEDURE `sp_check_group`(
           check_group int,
           ses smallint unsigned,
           keyno int,
           checkstate bool,
           depth int)
begin
    declare gid int;
    declare cur1 cursor for select ClassID from DevClasses where Parent = check_group;
    declare continue handler for sqlstate '02000' set gid = null; 


      if (depth < 5) then
            if  (checkstate = true) then
                 insert into SessionDevice(DeviceID, SessionID, KeyIndex)
                       select `DeviceList`.`DevID`, ses, keyno from DeviceList where parent = check_group
                on duplicate key update SessionID = values(SessionID);                
            else
                 delete SessionDevice from SessionDevice , DeviceList 
                       where SessionDevice.SessionID = ses and SessionDevice.KeyIndex = keyno 
                                     and SessionDevice.DeviceID = DeviceList.DevID and
                                      DeviceList.parent = check_group;
            end if;  

       open cur1; 
       fetch cur1 into gid; 

       while ( gid is not null )  do
         call sp_check_group(gid, ses, keyno, checkstate, depth+1); 
         fetch cur1 into gid; 
       end while; 
 end if; 
end$$

DELIMITER ;

-- -----------------------------------------------------
-- procedure sp_copy_mode
-- -----------------------------------------------------

USE `nccs`;
DROP procedure IF EXISTS `nccs`.`sp_copy_mode`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` PROCEDURE `sp_copy_mode`(
    old_modeid int,
    new_enabled boolean
    )
begin
declare new_modeid int default null;

declare old_session smallint default null;
declare new_session smallint default null;

declare mode_task_cur cursor for select  SessionID  from PlaySessions where BrdMode = old_modeid;  
declare continue handler for sqlstate '02000' set old_session = null;

  -- first step: copy mode record
  insert into BroadcastMode(ModeName, Priority, Enabled, StartTime, StopTime, TimeStyle, Active)  
           (select concat(ModeName, " copy"), Priority, new_enabled, StartTime, StopTime, TimeStyle, false from BroadcastMode where idBroadcastMode=old_modeid) ;
   
   set new_modeid = last_insert_id();
   
   if (new_modeid is not null) then
      -- copy mode members;
      insert into BrdModeMember(BrdModeID,DeviceID)  (select new_modeid,DeviceID from BrdModeMember where BrdModeID =  old_modeid);
      
      -- copy mode tasks;
      open  mode_task_cur;  
       fetch mode_task_cur into old_session;  
         
      while ( old_session is not null) do
            set new_session = get_idle_sessionid(false);
             insert into PlaySessions(SessionID,SessionName,SessionType,Priority,`Status`,CircleLength,ClassID,PlayerID,Parent,BrdMode,
                                                                MemberMode,StreamType,SysEnabled,PlayMode, AudioGain)
                                   (select new_session,SessionName,SessionType,Priority,`Status`,CircleLength,ClassID,PlayerID,Parent,new_modeid,
                                                                MemberMode,StreamType,SysEnabled, PlayMode, AudioGain
                                                                from PlaySessions where SessionID = old_session);
            
            insert into PlaySessionTime(SessionID,WeekDay,PlayTime,TempFlag) 
                          (select new_session,WeekDay,PlayTime,TempFlag from PlaySessionTime where SessionID = old_session);
            
            insert into PlayListFiles(FileID,SequenceID,SessionID,Duration,KeyIndex,PlayerID) 
                          (select FileID,SequenceID,new_session,Duration,KeyIndex,PlayerID from PlayListFiles where SessionID = old_session);
                          
             insert into SessionDevice(DeviceID,SessionID,KeyIndex,DevDisabled)
                           (select  DeviceID,new_session,KeyIndex,DevDisabled from  SessionDevice where SessionID = old_session);
             
             fetch mode_task_cur into old_session;  

      end while;
      close mode_task_cur;
   end if;
end$$

DELIMITER ;

-- -----------------------------------------------------
-- procedure sp_del_media_class
-- -----------------------------------------------------

USE `nccs`;
DROP procedure IF EXISTS `nccs`.`sp_del_media_class`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` PROCEDURE `sp_del_media_class`(classid int)
BEGIN
      UPDATE MediaFiles SET ClassID=0 WHERE (Parent=classid) ;
	DELETE FROM MediaClasses WHERE ID = classid;
END$$

DELIMITER ;

-- -----------------------------------------------------
-- procedure sp_del_media_file
-- -----------------------------------------------------

USE `nccs`;
DROP procedure IF EXISTS `nccs`.`sp_del_media_file`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` PROCEDURE `sp_del_media_file`(userid int, media_id int)
BEGIN

	declare tmp_own int default null;
	declare tmp_priority int;
	declare tmp_mediaid int;
	declare mediacurs cursor for select MediaID from MediaFiles where Parent = media_id;
	declare continue handler for not found,1329,sqlstate '02000' set tmp_mediaid = null;

	select func_get_mediafile_Owner(media_id) into tmp_own;
	select Priority into tmp_priority from Users where User_ID = userid;

	if(((tmp_own is not null) and (tmp_own = userid)) or 
		((tmp_priority is not null) and (tmp_priority = 0))) then

		open mediacurs;
		fetch mediacurs into tmp_mediaid;
			
		while(tmp_mediaid is not null) do
			call sp_del_media_file(userid,tmp_mediaid);
			fetch mediacurs into tmp_mediaid;
		end while;
		
		/** del current media_id */
		if ( not exists (select PlayingFileID from  PlayingSessions where PlayingFileID = media_id)) then
			DELETE FROM PlayListFiles WHERE FileID = media_id;
			DELETE FROM MediaFiles WHERE MediaID = media_id; 
		end if;

	end if;

END$$

DELIMITER ;

-- -----------------------------------------------------
-- procedure sp_del_session_class
-- -----------------------------------------------------

USE `nccs`;
DROP procedure IF EXISTS `nccs`.`sp_del_session_class`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` PROCEDURE `sp_del_session_class`(classid int)
BEGIN
	UPDATE PlaySessions SET ClassID=NULL WHERE ClassID = classid;
	DELETE FROM SessionClasses WHERE (ClassID=classid);
END$$

DELIMITER ;

-- -----------------------------------------------------
-- procedure sp_delete_device
-- -----------------------------------------------------

USE `nccs`;
DROP procedure IF EXISTS `nccs`.`sp_delete_device`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` PROCEDURE `sp_delete_device`(dev_id varchar(50))
begin
-- delete devices
delete from UserDevices where DevID = dev_id;
delete from DevCtrlSchedule where DevID = dev_id;
delete from SessionDevice where DeviceID = dev_id;
delete from BrdModeMember where DeviceID = dev_id;
delete from DeviceList where DevID = dev_id;

-- delete player
delete from PlaySessions where PlayerID = dev_id;
delete from PlayerKeys where PlayerID = dev_id;
delete from Players where PlayerID = dev_id;
end$$

DELIMITER ;

-- -----------------------------------------------------
-- procedure sp_delete_group
-- -----------------------------------------------------

USE `nccs`;
DROP procedure IF EXISTS `nccs`.`sp_delete_group`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` PROCEDURE `sp_delete_group`(GrpID int)
begin
delete from PlayGroupDevices where GroupID = GrpID;
delete from PlaySessionGroups where GroupID = GrpID;
delete from PlayGroups where GroupID = GrpID;
end$$

DELIMITER ;

-- -----------------------------------------------------
-- function sp_dev_belong_group
-- -----------------------------------------------------

USE `nccs`;
DROP function IF EXISTS `nccs`.`sp_dev_belong_group`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` FUNCTION `sp_dev_belong_group`(dev varchar(50), groupid int) RETURNS tinyint(1)
begin
    declare ret boolean default false ;
    declare gid int default 0;
   
   set gid  = groupid;
   
      if (groupid is null) or (groupid = 0) then
       return true;
    end if;
    
    if (dev is null)  then
       return false;
    end if;
    
   select Parent into gid  from  DeviceList   where DevID = dev;
   
   if (gid = groupid) then
       return true;
    end if;
    
    while (( gid is not null ) and (gid <> 0))  do
         select Parent into gid from  DevClasses   where ClassID = gid;
 
         if (gid = groupid) then
               return true;
          end if; 
    end while;        
   return false;   
end$$

DELIMITER ;

-- -----------------------------------------------------
-- procedure sp_dev_keepalive
-- -----------------------------------------------------

USE `nccs`;
DROP procedure IF EXISTS `nccs`.`sp_dev_keepalive`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` PROCEDURE `sp_dev_keepalive`(
    devid varchar(50),
    dev_name varbinary(32),
    dev_status  tinyint,
    power tinyint,
    fault tinyint,
    proj  tinyint,
    autual_ses smallint unsigned,
    rf_dev_status binary(16),
    ip_addr varchar(50)
    )
BEGIN
    declare tmp int;
    INSERT INTO DeviceList(DevID,Dev_Name) VALUES (devid, dev_name)
        ON DUPLICATE KEY UPDATE Dev_Name= VALUES(Dev_Name);
    
    set tmp = get_network(ip_addr);
        
    INSERT INTO DeviceStatus(DeviceID,  DeviceStatus,State_SysPower, 
                                                                 State_FaultStatus, State_ProjectorStatus, ActualSessionID,
                                                                  RfDevStatus, IpAddress, NetworkID) 
          VALUES (devid,  dev_status,   power,     fault,    proj,   autual_ses,  rf_dev_status, ip_addr, tmp)
          ON DUPLICATE KEY UPDATE 
          DeviceStatus= VALUES(DeviceStatus), State_SysPower = VALUES(State_SysPower), 
          State_FaultStatus= VALUES(State_FaultStatus),
          State_ProjectorStatus = VALUES(State_ProjectorStatus), 
          ActualSessionID = VALUES(ActualSessionID),
          RfDevStatus =  VALUES(RfDevStatus),
          IpAddress = VALUES(IpAddress),
          NetworkID = VALUES(NetworkID);
          
END$$

DELIMITER ;

-- -----------------------------------------------------
-- procedure sp_get_dev_ctrl_tasks
-- -----------------------------------------------------

USE `nccs`;
DROP procedure IF EXISTS `nccs`.`sp_get_dev_ctrl_tasks`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` PROCEDURE `sp_get_dev_ctrl_tasks`(dev_id varchar(50),
        start_datetime datetime)
label_pro: begin
         declare check_day date;
         declare check_start time;
         declare check_stop time;
         declare check_week int;
         
         create temporary table `tmp_dev_tasks` (
                            task_time int,
                            dev_ctrl     int
         ) engine = memory;

         set check_day = date(start_datetime);
         set check_start = time(start_datetime);
         set check_stop = '23:59:59';
         
         select AlteredScheduleDay into check_week from AlternateDate where SpecialDate = check_day;
         if check_week is null then 
              set check_week = weekday(check_day);
         end if;    
         

         
          insert  into tmp_dev_tasks(task_time, dev_ctrl)
            select UNIX_TIMESTAMP(date_add(check_day, interval time(a.PlayTime) hour_second) ),  a.SysEnabled
                  from  (select a.PlayTime, a.WeekDay, b.SessionID, 
                                      b.BrdMode, b.SysEnabled, 
                                      b.MemberMode, b.Priority, c.Priority as modepriority
                                  from PlaySessionTime a
                                  left join PlaySessions b on a.SessionID = b.SessionID
                                  left join BroadcastMode c on c.idBroadcastMode =  b.BrdMode 
                                   where  b.SysEnabled is not null and 
                                                   (check_week =  a.WeekDay  or b.BrdMode > 0) and  
                                                   check_start <= time(a.PlayTime) and 
                                                   check_stop > time(a.PlayTime))  as a
                left join BroadcastMode b on 
                                   b.idBroadcastMode = func_get_dev_mode(dev_id, 
                                                                                           date_add(check_day, interval time(a.PlayTime) hour_second)) 
                left join SessionDevice  c on c.SessionID = a.SessionID and c.DeviceID = dev_id 
            where 
                  ((a.MemberMode = true) and (b.idBroadcastMode = a.BrdMode))  or
                   ((a.MemberMode = false or a.MemberMode is null)   and
                         c.DevDisabled = false and
                         ( ( (a.Priority < b.Priority or b.Priority is null) and (a.BrdMode is null or a.BrdMode = 0) ) or
                          (a.BrdMode > 0 and (a.modepriority <  b.Priority or b.Priority is null)) ));        
       
       -- Get next day scheduled tasks
         set check_day = date_add(check_day, interval 1 day) ;
         set check_start = '00:00:00';
         set check_stop = time(start_datetime);
         
         select AlteredScheduleDay into check_week from AlternateDate where SpecialDate = check_day;
         if check_week is null then 
              set check_week = weekday(check_day);
         end if;    
         
         
         insert  into tmp_dev_tasks(task_time, dev_ctrl)
             select UNIX_TIMESTAMP(date_add(check_day, interval time(a.PlayTime) hour_second) ),  a.SysEnabled
                  from  (select a.PlayTime, a.WeekDay, b.SessionID, 
                                      b.BrdMode, b.SysEnabled, 
                                      b.MemberMode, b.Priority, c.Priority as modepriority
                                  from PlaySessionTime a
                                  left join PlaySessions b on a.SessionID = b.SessionID
                                  left join BroadcastMode c on c.idBroadcastMode =  b.BrdMode 
                                   where  b.SysEnabled is not null and 
                                                   (check_week =  a.WeekDay  or b.BrdMode > 0) and  
                                                   check_start <= time(a.PlayTime) and 
                                                   check_stop > time(a.PlayTime))  as a
                left join BroadcastMode b on 
                                   b.idBroadcastMode = func_get_dev_mode(dev_id, 
                                                                                           date_add(check_day, interval time(a.PlayTime) hour_second)) 
                left join SessionDevice  c on c.SessionID = a.SessionID and c.DeviceID = dev_id 
       where 
                  ((a.MemberMode = true) and (b.idBroadcastMode = a.BrdMode))  or
                   ((a.MemberMode = false or a.MemberMode is null)   and
                         c.DevDisabled = false and
                         ( ( (a.Priority < b.Priority or b.Priority is null) and (a.BrdMode is null or a.BrdMode = 0) ) or
                          (a.BrdMode > 0 and (a.modepriority <  b.Priority or b.Priority is null)) ));          
                          
      select  task_time, dev_ctrl  from   tmp_dev_tasks order by   task_time limit 10;      
      
      drop table tmp_dev_tasks;
         
end$$

DELIMITER ;

-- -----------------------------------------------------
-- procedure sp_get_dev_scheduled_tasks
-- -----------------------------------------------------

USE `nccs`;
DROP procedure IF EXISTS `nccs`.`sp_get_dev_scheduled_tasks`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` PROCEDURE `sp_get_dev_scheduled_tasks`(dev_id varchar(50),
        start_datetime datetime,
        stop_datetime datetime)
label_pro: begin
         declare check_day date;
         declare check_start time;
         declare check_stop time;
         declare check_week int;

         set check_day = date(start_datetime);
         set check_start = time(start_datetime);
         set check_stop = time(stop_datetime);
         
         select AlteredScheduleDay into check_week from AlternateDate where SpecialDate = check_day;
         if check_week is null then 
              set check_week = weekday(check_day);
         end if;    
         
         if (check_day <> date(stop_datetime)) or (check_start >= check_stop) then
             leave label_pro;
         end if;    
         
         select a.ScheduleID, a.TempFlag, time(a.PlayTime), a.SessionID,a.SessionName, 
                                      a.BrdMode, a.SessionType, a.LedTimeCount, a.LedBaseState, a.LedBaseText, 
                                      a.LedMsgText, a.SysEnabled, a.MemberMode, a.Priority, a.modepriority,
                                      b.idBroadcastMode, c.DevDisabled
                  from  (select a.ScheduleID, a.TempFlag, a.PlayTime, a.WeekDay, b.SessionID, b.SessionName, 
                                      b.BrdMode, b.SessionType, b.LedTimeCount, b.LedBaseState, b.LedBaseText, 
                                      b.LedMsgText, b.LedBaseLightColor, b.LedTextLightColor, b.SysEnabled, b.StreamType, 
                                      b.MemberMode, b.Priority, c.Priority as modepriority
                                  from PlaySessionTime a
                                  left join PlaySessions b on a.SessionID = b.SessionID
                                  left join BroadcastMode c on c.idBroadcastMode =  b.BrdMode 
                                   where  (check_week =  a.WeekDay  or b.BrdMode > 0)and  
                                                   check_start <= time(a.PlayTime) and 
                                                   check_stop > time(a.PlayTime))  as a
                left join BroadcastMode b on 
                                   b.idBroadcastMode = func_get_dev_mode(dev_id, 
                                                                                           date_add(check_day, interval time(a.PlayTime) hour_second)) 
                left join SessionDevice  c on c.SessionID = a.SessionID and c.DeviceID = dev_id 
       where 
                  ((a.MemberMode = true) and (b.idBroadcastMode = a.BrdMode))  or
                   ((a.MemberMode = false or a.MemberMode is null)   and
                         c.DevDisabled = false and
                         ( ( (a.Priority < b.Priority or b.Priority is null) and (a.BrdMode is null or a.BrdMode = 0) ) or
                          (a.BrdMode > 0 and (a.modepriority <  b.Priority or b.Priority is null)) ));                      
         
end$$

DELIMITER ;

-- -----------------------------------------------------
-- function sp_group_dev_ctrl_func
-- -----------------------------------------------------

USE `nccs`;
DROP function IF EXISTS `nccs`.`sp_group_dev_ctrl_func`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` FUNCTION `sp_group_dev_ctrl_func`(
    ctrl_devid varchar(50),
    ctrl_groupid int,
    cmd int,
    state int,
    extargs varchar(256)) RETURNS int(11)
begin
    declare tmp int default 0 ;
    
    if (ctrl_devid is not null) and (ctrl_devid <>"") then
        select sp_send_dev_ctrl_function(ctrl_devid, IpAddress, cmd,state, 0, 0, extargs )  into tmp from DeviceStatus 
        where DeviceID = ctrl_devid;
     end if;
     
     if (ctrl_groupid is not null) and (ctrl_groupid <> 0) then
         -- set @@max_sp_recursion_depth = 5;       
         -- call sp_send_group_cmd(ctrl_groupid, cmd, state, extargs);
         insert into tmp_result
           select sp_send_dev_ctrl_function(DeviceStatus.DeviceID, DeviceStatus.IpAddress, cmd,state, 0, 0, extargs ) 
               from DeviceStatus , DeviceList
               where  DeviceList.DisableParentSchedule = false and
                              sp_dev_belong_group(DeviceList.DevID, ctrl_groupid) and 
                              DeviceList.DevID = DeviceStatus.DeviceID ;
                              
          delete from tmp_result;                    

     end if;

    return tmp;
end$$

DELIMITER ;

-- -----------------------------------------------------
-- procedure sp_keepalive_send
-- -----------------------------------------------------

USE `nccs`;
DROP procedure IF EXISTS `nccs`.`sp_keepalive_send`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` PROCEDURE `sp_keepalive_send`()
begin
 -- select func_keepalive_transmit(b.idSubNetwork, b.IpAddress, a.IpAddress) from SubNetwork as b 
 --   left join DeviceStatus a  on b.idSubNetwork = a. NetworkID group by  idSubNetwork;
  select func_keepalive_transmit(c.idSubNetwork, c.IpAddress, c.proxy) from 
( select b.idSubNetwork, b.IpAddress, a.IpAddress as proxy from SubNetwork as b 
    left join (select NetworkID, IpAddress from DeviceStatus group by  NetworkID) as a on b.idSubNetwork = a. NetworkID) as c;
end$$

DELIMITER ;

-- -----------------------------------------------------
-- procedure sp_player_keepalive
-- -----------------------------------------------------

USE `nccs`;
DROP procedure IF EXISTS `nccs`.`sp_player_keepalive`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` PROCEDURE `sp_player_keepalive`(
    devid varchar(50),
    player_type tinyint,   -- 0: Autobroadcast player, 1: caller
    player_status tinyint, -- 0: stoped, 1:playing
    actual_ses int , 
    keymap int,           -- recevier members
    key_type tinyint,  -- 0: group call; 1: device call
    ip_addr varchar(50)
    )
BEGIN
    declare net_id int;
    declare key_index int;
    declare group_en tinyint;
    declare dev_en tinyint;
    
if ((player_type <> 2) or exists(select PlayerID from Players where PlayerID = devid)) then
   

    insert into Players(PlayerID, PlayerType ) values (devid, player_type)
        on duplicate key update PlayerType= values(PlayerType);
    
    set net_id = get_network(ip_addr);
        
    insert into PlayerStatus(PlayerID,  ActualSesID, IpAddress, NetID, PlayType)
        values (devid,  actual_ses, ip_addr, net_id, player_type)
        on duplicate key update
            IpAddress = values(IpAddress), ActualSesID =  values(ActualSesID), NetID = values(NetID);

    -- assign an idle port to the player
    update   PlayerStatus set PlayPort = get_idle_port() where PlayPort is null and PlayerID = devid;


    if ((player_type <> 0) and (player_type <> 8)) then
        if (player_status = 1) then
            update   PlayerStatus set SessionID = (select SessionID from PlaySessions where PlayerID = devid) 
                   where  (PlayerID = devid) and (SessionID is null or  SessionID = 0);
        else 
            if (player_status = 0) then
                update   PlayerStatus set SessionID = 0
                    where  (PlayerID = devid) and (SessionID <> 0) ;
            end if;           
        end if;

         -- update keepalive time
        insert into PlayerAlive(PlayerID, ReFreshTime) values(devid, now()) 
            on duplicate key update ReFreshTime=values(ReFreshTime);
    end if;    
 

    if (player_type = 1) then

        -- update key map
        set  key_index = 0;
        while (key_index < 16) do
            if (keymap & (0x01 << key_index) <> 0) then
                if (key_type = 0) then
                    set group_en = 0;
                    set dev_en = 1;
                else
                    set dev_en = 0;
                    set group_en = 1;
                end if;    
            else
                set dev_en = 1;
                set group_en = 1;
            end if;
 
    
            insert into PlayerKeys(PlayerID, `Index`, GroupDisable, DevDisable)  values (devid, key_index + 1, group_en, dev_en)
                on duplicate key update GroupDisable=values(GroupDisable), DevDisable=values(DevDisable) ;
 
		    set  key_index =key_index + 1;

        end while;

    end if;
end if; 
end$$

DELIMITER ;

-- -----------------------------------------------------
-- procedure sp_reset_player
-- -----------------------------------------------------

USE `nccs`;
DROP procedure IF EXISTS `nccs`.`sp_reset_player`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` PROCEDURE `sp_reset_player`(player varchar(50))
BEGIN
update PlayerStatus set SessionID = 0, ActualSesID = 0 where PlayerID = player ;
END$$

DELIMITER ;

-- -----------------------------------------------------
-- procedure sp_send_dev_cfg_cmd
-- -----------------------------------------------------

USE `nccs`;
DROP procedure IF EXISTS `nccs`.`sp_send_dev_cfg_cmd`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` PROCEDURE `sp_send_dev_cfg_cmd`(
    devid VARCHAR(50),
    Ipaddr VARCHAR(50),
    devcfg VARCHAR(1024)
    )
BEGIN
    declare tmp int;
    set tmp = device_config(Ipaddr, devid,  devcfg);
END$$

DELIMITER ;

-- -----------------------------------------------------
-- procedure sp_send_dev_ctrl_cmd
-- -----------------------------------------------------

USE `nccs`;
DROP procedure IF EXISTS `nccs`.`sp_send_dev_ctrl_cmd`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` PROCEDURE `sp_send_dev_ctrl_cmd`(
    devid varchar(50),
    Ipaddr varchar(50),
    cmd tinyint unsigned,
    para1 int unsigned,
    para2 int unsigned,
    para3 int unsigned,
    extarg varchar(256)
    )
begin
    declare ret int;
    
    if (cmd = 62) then 
        update `nccs`.`DeviceDesiredStaus` SET `SysEnabled`= para1 WHERE `DeviceID`=devid;
	else
		set ret = device_ctrl(Ipaddr, devid, cmd, para1, para2, para3);
	end if;
end$$

DELIMITER ;

-- -----------------------------------------------------
-- function sp_send_dev_ctrl_function
-- -----------------------------------------------------

USE `nccs`;
DROP function IF EXISTS `nccs`.`sp_send_dev_ctrl_function`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` FUNCTION `sp_send_dev_ctrl_function`(
    user_id int,
    devid varchar(50),
    Ipaddr varchar(50),
    cmd int ,
    para1 int ,
    para2 int ,
    para3 int ,
    extarg varchar(256)
    ) RETURNS int(11)
BEGIN

    declare ret int;  
    
        if (cmd = 62) then 
             update `nccs`.`DeviceDesiredStaus` SET `SysEnabled`= para1 WHERE `DeviceID`=devid;
      end if;
    
    if (cmd = 0x40) then
        set ret = device_message(Ipaddr, devid,  para1, extarg);
        insert into DeviceLog(DeviceID,DateTime,Event,State,CtrlUser,MsgContext) values(devid, now(), 4, para1, user_id,  extarg);
    else
       set ret = device_ctrl(Ipaddr, devid, cmd, para1, para2, para3);
    end if;
     
     return ret;
END$$

DELIMITER ;

-- -----------------------------------------------------
-- procedure sp_send_group_cmd
-- -----------------------------------------------------

USE `nccs`;
DROP procedure IF EXISTS `nccs`.`sp_send_group_cmd`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` PROCEDURE `sp_send_group_cmd`(
    groupid int,
    cmd int,
    state int,
    extargs varchar(256))
begin

       insert into tmp_result 
              select sp_send_dev_ctrl_function(null,DeviceID, IpAddress, cmd,state, 0, 0, extargs) from DeviceStatus
               where IpAddress is not null  and sp_dev_belong_group(DeviceID,  groupid) = true;
               
        delete from   tmp_result  ;
end$$

DELIMITER ;

-- -----------------------------------------------------
-- procedure sp_session_clean_up
-- -----------------------------------------------------

USE `nccs`;
DROP procedure IF EXISTS `nccs`.`sp_session_clean_up`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` PROCEDURE `sp_session_clean_up`()
begin
 -- delete obseloted sessions
 delete PlaySessions from PlaySessions 
where (SessionType = 0 or SessionType = 8) and 
               (not exists (select ScheduleID from PlaySessionTime where SessionID = PlaySessions.SessionID)) and
               (not exists (select PlayerID from PlayingSessions where SessionID = PlaySessions.SessionID) );

end$$

DELIMITER ;

-- -----------------------------------------------------
-- procedure sp_session_ctrl
-- -----------------------------------------------------

USE `nccs`;
DROP procedure IF EXISTS `nccs`.`sp_session_ctrl`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` PROCEDURE `sp_session_ctrl`(ses_id  smallint unsigned, ses_status int, sche_id int)
begin
declare Player int default null;
declare ses_type tinyint unsigned default 0;


if (ses_status = 1) then
     -- start session
     if exists(select Player = PlayerID from PlayerStatus where SessionID = ses_id) then
            -- session has been started and pasued, restart it
            update PlayingSessions set  Pause = 0 where SessionID = ses_id;
     else
            -- start a new session
            select SessionType into ses_type from PlaySessions where SessionID = ses_id limit 1;

            if ((ses_type < 8)  and (ses_type <> 1)) then
                -- start an audio 
                update PlayerStatus set SessionID = ses_id,  ActualSesID = ses_id,ScheduleID = sche_id 
                            where (SessionID = 0 OR SessionID is null)  and 
                                           (ActualSesID = 0 OR ActualSesID is null)   and PlayType = 0 limit 1;
              else 
                     -- start an video 
                          update PlayerStatus set SessionID = ses_id,  ActualSesID = ses_id,ScheduleID = sche_id 
                            where (SessionID = 0 OR SessionID is null)  and 
                                           (ActualSesID = 0 OR ActualSesID is null)   and PlayType = 8 limit 1;                
             end if;                              
      end if;
else
      if (ses_status = 0) then
            update PlayerStatus set SessionID = 0 where (SessionID = ses_id) limit 1;
       else
            update PlayingSessions set  Pause = 1 where SessionID = ses_id;
        end if;   
end if;
end$$

DELIMITER ;

-- -----------------------------------------------------
-- function sp_session_start
-- -----------------------------------------------------

USE `nccs`;
DROP function IF EXISTS `nccs`.`sp_session_start`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` FUNCTION `sp_session_start`(
                                   ses_id int, 
                                   sche_id int,
                                   flag tinyint,
                                   stream tinyint,
                                   brd_mode int,
                                   mode_member boolean,
                                   sys_enable tinyint ,
                                   rf_dev_ctrl_cmd binary(16)) RETURNS tinyint(4)
begin
     declare run_priority int default  null;
     if (flag = 2) then 
         return 0;
     end if;
     
    if (stream > 0) then
         call sp_session_ctrl(ses_id, 1, sche_id);
     end if;
     
     if  (brd_mode > 0) then
         if  (mode_member = true)  then
                 update DeviceDesiredStaus set
                             SysEnabled = case when sys_enable is not null then  
                                                                                   sys_enable else DeviceDesiredStaus.SysEnabled end ,                             
                              DeviceDesiredStaus.RfDevCtrl =    update_rf_ctrl(DeviceDesiredStaus.RfDevCtrl, rf_dev_ctrl_cmd)                                              
                       where   DeviceDesiredStaus.BrdMode =    brd_mode;      
            else
                    select  Priority into run_priority from BroadcastMode where idBroadcastMode =  brd_mode limit 1;
                    
                    update DeviceDesiredStaus, SessionDevice set
                             DeviceDesiredStaus.SysEnabled = case when sys_enable is not null then  
                                                                                   sys_enable else DeviceDesiredStaus.SysEnabled end ,                              
                              DeviceDesiredStaus.RfDevCtrl =    update_rf_ctrl(DeviceDesiredStaus.RfDevCtrl, rf_dev_ctrl_cmd)                                                     
                       where   (SessionDevice.SessionID = ses_id) and (SessionDevice.DevDisabled = false) and 
                                       (DeviceDesiredStaus.DeviceID =    SessionDevice.DeviceID) and
                                       ((DeviceDesiredStaus.ModePriority is null) or (DeviceDesiredStaus.ModePriority >= run_priority));    
                    
            end if;
     else 
          -- non mode task
          select  Priority into run_priority from PlaySessions where SessionID =  ses_id limit 1;
          
          update DeviceDesiredStaus, SessionDevice set
                             DeviceDesiredStaus.SysEnabled = case when sys_enable is not null then  
                                                                                   sys_enable else DeviceDesiredStaus.SysEnabled end ,                              
                               DeviceDesiredStaus.RfDevCtrl =    update_rf_ctrl(DeviceDesiredStaus.RfDevCtrl, rf_dev_ctrl_cmd)                                                 
                       where   (SessionDevice.SessionID = ses_id) and (SessionDevice.DevDisabled = false) and 
                                       (DeviceDesiredStaus.DeviceID =    SessionDevice.DeviceID) and
                                       ((DeviceDesiredStaus.ModePriority is null) or (DeviceDesiredStaus.ModePriority > run_priority));    
          
          
      end if; 
	
	if (stream = 0) and (flag = 1) then
		return 127; /*mark the task shall be deleted immidicately*/
	end if;
	
    return flag;
	
    
end$$

DELIMITER ;

-- -----------------------------------------------------
-- procedure sp_timer_deamon
-- -----------------------------------------------------

USE `nccs`;
DROP procedure IF EXISTS `nccs`.`sp_timer_deamon`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` PROCEDURE `sp_timer_deamon`()
begin

declare last_time datetime default '2012-1-1 00:00:00';
declare cur_time datetime; 

-- get last processed time
select LastTime into last_time from LastProcessedTime where LastTimeID = 1;

set  cur_time = now();

if ((last_time > cur_time) or (timestampdiff(second, last_time, cur_time) > 10)) then
    set last_time = timestampadd(second, -2, cur_time);
 end if;   
 
-- delete expired messages
delete from Messages where abs(timestampdiff(second, MsgTime, cur_time)) > 10;
delete from TempIcCard where abs(timestampdiff(second, RecordTime, cur_time)) > 2;

-- update mode status
update BroadcastMode set
             Active = ! Active
             where Enabled = true and
                            (func_check_mode_daytime(TimeStyle, 
                                                                                      case when Active = false then StartTime else StopTime end, 
                                                                                      last_time, cur_time) = true);
             
-- Update device modes
insert into DeviceDesiredStaus(DeviceID, BrdMode, ModePriority)
        select  DeviceID, BrdModeID, Priority from v_DeviceModes
        on duplicate key update BrdMode = values(BrdMode), ModePriority = values(ModePriority);
                      
 -- play  on time tasks
update PlaySessionTime
                 left join PlaySessions on PlaySessionTime.SessionID = PlaySessions.SessionID
                 set PlaySessionTime.TempFlag = sp_session_start(PlaySessions.SessionID, PlaySessionTime.ScheduleID, 
                                                                                                                           PlaySessionTime.TempFlag,
                                                                                                                           PlaySessions.StreamType, PlaySessions.BrdMode, 
                                                                                                                           PlaySessions.MemberMode, 
                                                                                                                           PlaySessions.SysEnabled, 
                                                                                                                           PlaySessions.RfDevCtrl)
  where  func_check_session_daytime(PlaySessions.BrdMode, PlaySessionTime. WeekDay, 
                                                                              PlaySessionTime.PlayTime, last_time, cur_time)  = true;

delete from PlaySessionTime where TempFlag = 127;
 
 -- delete expired alterdate entries
delete from AlternateDate where date(cur_time) > SpecialDate;

-- deleted offline Players
delete PlayerStatus,  PlayerAlive from PlayerStatus,  PlayerAlive
where (PlayerStatus.PlayerID = PlayerAlive.PlayerID) and  
             timestampdiff(second, PlayerAlive.RefreshTime, cur_time) > 10;
      
insert into LastProcessedTime(LastTimeID, LastTime) values (1, cur_time) 
              on duplicate key update LastTime = values(LastTime);

-- call sp_session_clean_up();

end$$

DELIMITER ;

-- -----------------------------------------------------
-- procedure sp_update_dev_session
-- -----------------------------------------------------

USE `nccs`;
DROP procedure IF EXISTS `nccs`.`sp_update_dev_session`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` PROCEDURE `sp_update_dev_session`(dev_id varchar(50))
begin
 declare modeid int default 0; 
 declare modepriority int default null;
 declare sessionid smallint unsigned default null;
 declare sessionport int default 0; 
 declare sessiontype tinyint default 0; 
 declare streamType tinyint default 1; 
 declare valid boolean default false; 

 -- lock tables DeviceDesiredStaus write;
 
 select DeviceDesiredStaus.SessionValid,  DeviceDesiredStaus.BrdMode, BroadcastMode.Priority
               into valid, modeid,  modepriority from DeviceDesiredStaus 
               left join BroadcastMode on BroadcastMode.idBroadcastMode = DeviceDesiredStaus.BrdMode
               where DeviceID = dev_id;
   
  if  not (valid=true) then
                
       select SessionList.SessionID,  SessionList.MultiPort , SessionList.SesType,SessionList.StreamType
                 into  sessionid, sessionport , sessiontype, streamType from 
                       (select PlaySessions.SessionID,  PlaySessions.Priority,  PlayingSessions.PlayerID,  
                                        PlayingSessions.MultiPort , PlaySessions.BrdMode, PlaySessions.MemberMode, 
                                        PlayingSessions.SesType, PlayingSessions.StreamType
                                  from PlayingSessions 
                                  left join PlaySessions on PlayingSessions.SessionID = PlaySessions.SessionID 
                                  where   (func_check_dev_stream(dev_id,PlayingSessions.StreamType) = true) and
                                                   (((modeid = 0 or modeid is null ) and (PlaySessions.MemberMode = false) )
                                                               or (PlaySessions.Priority < modepriority) or (PlaySessions.BrdMode = modeid))) 
                                as SessionList                   
               left join SessionDevice on (SessionDevice.DeviceID = dev_id) and 
                                                                      (SessionDevice.SessionID = SessionList.SessionID) and
                                                                      (not DevDisabled = 1)
               left join  PlayerKeys on PlayerKeys.PlayerID = SessionList.PlayerID  and PlayerKeys.GroupDisable = 0                                                    
               where
                            (SessionDevice.DeviceID  is not null) or (SessionList.BrdMode = modeid and  SessionList.MemberMode = true) or
                             (PlayerKeys.GroupID is not null and sp_dev_belong_group(dev_id , PlayerKeys.GroupID))  
                      order by SessionList.Priority, SessionList.SessionID LIMIT 1;
                      
      insert into DeviceDesiredStaus (DeviceID, SessionID, BrdPort,  SessionType, StreamType, SessionValid)
              values(dev_id, sessionid, sessionport,  sessiontype, streamType, true)
              on duplicate key update                       
                  SessionID = values(SessionID), BrdPort = values(BrdPort), 
                  SessionType=values(SessionType),
                  StreamType = values(StreamType),  SessionValid = values(SessionValid);
              
 end if;
 
 -- unlock tables ;
 
select a.SessionID, a.BrdPort, a.SessionType, a.StreamType, a.SysEnabled, b.NetworkID , a.RfDevCtrl, c.SessionName
                 from DeviceDesiredStaus as a 
                     left join DeviceStatus b on a.DeviceID=b.DeviceID 
                     left join PlaySessions c on a.SessionID= c.SessionID
                          where a.DeviceID = dev_id;
  
end$$

DELIMITER ;

-- -----------------------------------------------------
-- procedure sp_fetch_playing_file
-- -----------------------------------------------------

USE `nccs`;
DROP procedure IF EXISTS `nccs`.`sp_fetch_playing_file`;

DELIMITER $$
USE `nccs`$$
create  procedure `sp_fetch_playing_file`(
    sesid smallint,
    file_seq int,
    remained_time int)
begin
	declare random tinyint default 0;
	declare maxid int default 0;

    select PlayMode into random from PlaySessions where  SessionID = sesid;

	if (random > 0) then
		if (remained_time <> 0) then            
           select max(b.SequenceID) into maxid from PlayListFiles b
				   left join MediaFiles c on b.FileID = c.MediaID 
					where b.SessionID = sesid and c.TotalTime > 0 and c.TotalTime < remained_time;
		   set maxid = round( rand() * maxid);
		   select b.FileID, b.Duration,b.SequenceID, c.Gain, c.FilePath, @@datadir    
                   from PlayListFiles b left join MediaFiles c on b.FileID = c.MediaID 
		               where  (b.SessionID = sesid) and (b.SequenceID >= maxid) and (c.TotalTime > 0) and (c.TotalTime < remained_time) 
                   order by SequenceID limit 0, 1;
		else
			if (file_seq = 0) then
			    select max(SequenceID) into maxid from PlayListFiles where SessionID = sesid;
			    set maxid = round( rand() * maxid);
			    select b.FileID, b.Duration,1, c.Gain, c.FilePath, @@datadir    
                   from PlayListFiles b left join MediaFiles c on b.FileID = c.MediaID 
		           where  (b.SessionID = sesid) and (b.SequenceID >= maxid) order by SequenceID limit 0, 1;
			else
                select null; 
            end if;
		end if;
    else 
        select b.FileID, b.Duration,b.SequenceID, c.Gain, c.FilePath, @@datadir    
               from PlayListFiles b left join MediaFiles c on b.FileID = c.MediaID 
		       where  (b.SessionID = sesid) and (b.SequenceID >= file_seq) order by SequenceID limit 0, 1;
    end if;
	 
    

END
$$

DELIMITER ;

-- -----------------------------------------------------
-- function func_IcCard_Authorize
-- -----------------------------------------------------

USE `nccs`;
DROP function IF EXISTS `nccs`.`func_IcCard_Authorize`;

DELIMITER $$
USE `nccs`$$
CREATE FUNCTION `func_IcCard_Authorize`(
          IcCard varchar(50),
          DeviceID varchar(50)
         ) RETURNS tinyint(1)
BEGIN
    declare userid int default null;
    
    select UserDevices.UserID into userid from Users
           left join UserDevices on Users.User_ID = UserDevices.UserID
         where Users.IcCard = IcCard and UserDevices.DevID = DeviceID;

    if (userid is not null) then
	    insert into TempIcCard values(userid, DeviceID, now());
    end if;
    
    return userid;
END$$

DELIMITER ;

-- -----------------------------------------------------
-- function func_dulicate_device
-- -----------------------------------------------------

USE `nccs`;
DROP function IF EXISTS `nccs`.`func_dulicate_device`;

DELIMITER $$
USE `nccs`$$
CREATE function func_dulicate_device (
    SrcDevice varchar(50),
	DstDevice varchar(50),
    mask tinyint unsigned) returns integer
BEGIN
    declare base_cfg varchar(704) default null;
	declare name_cfg varchar(256) default null;
    declare cfg varchar(960) default null;
    declare ret int default null;

    -- mask bit0: whether copy device configuration
    if ((mask & 0x01) <> 0) then  
       select SUBSTRING(hex(Dev_configuration), 257, 704) into base_cfg from DeviceList where DevID = SrcDevice; 
     
	   -- mask bit 1: whether copy device name and description
	   if ((mask & 0x02) <> 0) then
		   select SUBSTRING(hex(Dev_configuration), 1, 256) into name_cfg from DeviceList where DevID = SrcDevice; 
       else
           select SUBSTRING(hex(Dev_configuration), 1, 256) into name_cfg from DeviceList where DevID = DstDevice; 
	   end if;

       if (base_cfg is null) or (name_cfg is null) then
	       return 0;
	   end if;

       set cfg = CONCAT(name_cfg, base_cfg);
       /*send device config command*/
	   select device_config(IpAddress, DeviceID,  cfg) into ret from DeviceStatus where DeviceID = DstDevice;

       if not (ret = 497) then
          return 0;
       end if;
    end if;

    if ((mask & 0x08) <> 0) then
        update DeviceList set Parent = (select Parent from (select * from DeviceList) as tmp_table 
										where DevID = SrcDevice) where DevID = DstDevice;
    end if;

	-- copy device tasks data
    if ((mask & 0x04) <> 0) then
		delete from SessionDevice where DeviceID = DstDevice;
        insert into SessionDevice(DeviceID, SessionID, KeyIndex, DevDisabled) 
               select DstDevice, SessionID, KeyIndex, DevDisabled from SessionDevice where DeviceID = SrcDevice;
        
		delete from BrdModeMember where DeviceID = DstDevice;
        insert into BrdModeMember(BrdModeID, DeviceID) 
               select BrdModeID, DstDevice from BrdModeMember where DeviceID = SrcDevice;

		delete from UserDevices where DevID = DstDevice;
        insert into UserDevices(UserID, DevID) 
               select UserID, DstDevice from UserDevices where DevID = SrcDevice;

        delete from DevCtrlSchedule where DevID = DstDevice;
        insert into DevCtrlSchedule(DevID,ActionTime,`Action`,WeekDay,State,ExtArgs,`Disable`)
               select DstDevice,ActionTime,`Action`,WeekDay,State,ExtArgs,`Disable` from DevCtrlSchedule where DevID = SrcDevice; 
    end if;

    -- delete source device
    if ((mask & 0x80) <> 0) then
        delete from UserDevices where DevID = SrcDevice;
        delete from DevCtrlSchedule where DevID = SrcDevice;
        delete from SessionDevice where DeviceID = SrcDevice;
        delete from BrdModeMember where DeviceID = SrcDevice;
        delete from DeviceList where DevID = SrcDevice;
    end if;
    return 1;
END$$

DELIMITER ;

-- -----------------------------------------------------
-- function func_get_mediafile_Owner
-- -----------------------------------------------------

USE `nccs`;
DROP function IF EXISTS `nccs`.`func_get_mediafile_Owner`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` FUNCTION `func_get_mediafile_Owner`(mediaID int) RETURNS int
BEGIN
	declare medid int default null;
	declare pid int default null;
	declare own int default null;
	declare foldflag tinyint default null;

	select mediafile.Parent,mediafile.`Owner`,mediafile.Sysfolder,mediafile.MediaID into pid,own,foldflag,medid from MediaFiles mediafile where mediafile.MediaID = mediaID limit 1;
	if(medid is null) then
		set own = -1;
		return own;
	else
		if((foldflag is not null) and (foldflag = 1)) then
			if(own is null) then
				set own = 0;
			end if;
			return own;
		else
			while((pid is not null) and (pid <> 0)) do
				select mediafile.Parent,mediafile.`Owner`,mediafile.Sysfolder into pid,own,foldflag from MediaFiles mediafile where mediafile.MediaID = pid limit 1;
				
				if((foldflag is not null) and (foldflag = 1)) then
					if(own is null) then
						set own = 0;
					end if;
					return own;
				end if;

			end while;

		end if;
		set own = 0;
		return own;
	end if;
	
END$$

DELIMITER ;

-- -----------------------------------------------------
-- View `nccs`.`v_DeviceModes`
-- -----------------------------------------------------
DROP VIEW IF EXISTS `nccs`.`v_DeviceModes` ;
DROP TABLE IF EXISTS `nccs`.`v_DeviceModes`;
USE `nccs`;
CREATE 
     OR REPLACE ALGORITHM = UNDEFINED 
    DEFINER = `root`@`%` 
    SQL SECURITY DEFINER
VIEW `nccs`.`v_DeviceModes` AS
    select 
        `a`.`DevID` AS `DeviceID`,
        `b`.`BrdModeID` AS `BrdModeID`,
        `b`.`Priority` AS `Priority`
    from
        ((`nccs`.`DeviceList` `a`
        left join `nccs`.`v_active_mode_members` `b` ON ((`b`.`DeviceID` = `a`.`DevID`)))
        left join `nccs`.`v_active_mode_members` `c` ON (((`c`.`DeviceID` = `a`.`DevID`)
            and (`c`.`Priority` < `b`.`Priority`))))
    where
        isnull(`c`.`Priority`);

-- -----------------------------------------------------
-- View `nccs`.`v_Session_Files`
-- -----------------------------------------------------
DROP VIEW IF EXISTS `nccs`.`v_Session_Files` ;
DROP TABLE IF EXISTS `nccs`.`v_Session_Files`;
USE `nccs`;
CREATE  OR REPLACE ALGORITHM=UNDEFINED DEFINER=`root`@`%` SQL SECURITY 
DEFINER VIEW `nccs`.`v_Session_Files` AS 
select `a`.`SessionID` AS `SessionID`,`b`.`FileID` AS `FileID`,`b`.`SequenceID` AS `SequenceID`,
        `c`.`FileName` AS `FileName`,`c`.`TotalTime` AS `TotalTime`,`b`.`Duration` AS `PlayTime`,
        `c`.`Gain` AS `Gain`,`c`.`FileFmt` AS `FileFmt`,`c`.`FilePath` AS `FilePath` 
from ((`nccs`.`PlaySessions` `a` left join `nccs`.`PlayListFiles` `b` on((`a`.`SessionID` = `b`.`SessionID`))) 
left join `nccs`.`MediaFiles` `c` on((`b`.`FileID` = `c`.`MediaID`))) where (`b`.`FileID` is not null);

-- -----------------------------------------------------
-- View `nccs`.`v_active_mode_members`
-- -----------------------------------------------------
DROP VIEW IF EXISTS `nccs`.`v_active_mode_members` ;
DROP TABLE IF EXISTS `nccs`.`v_active_mode_members`;
USE `nccs`;
CREATE  OR REPLACE ALGORITHM=UNDEFINED DEFINER=`root`@`%` SQL SECURITY DEFINER VIEW `nccs`.`v_active_mode_members` AS select `nccs`.`BrdModeMember`.`DeviceID` AS `DeviceID`,`nccs`.`BroadcastMode`.`idBroadcastMode` AS `BrdModeID`,`nccs`.`BroadcastMode`.`Priority` AS `Priority` from (`nccs`.`BroadcastMode` left join `nccs`.`BrdModeMember` on((`nccs`.`BroadcastMode`.`idBroadcastMode` = `nccs`.`BrdModeMember`.`BrdModeID`))) where (`nccs`.`BroadcastMode`.`Active` = 1);

-- -----------------------------------------------------
-- View `nccs`.`v_session_info`
-- -----------------------------------------------------
DROP VIEW IF EXISTS `nccs`.`v_session_info` ;
DROP TABLE IF EXISTS `nccs`.`v_session_info`;
USE `nccs`;
CREATE  OR REPLACE ALGORITHM=UNDEFINED DEFINER=`root`@`%` SQL SECURITY DEFINER VIEW `nccs`.`v_session_info` AS select `nccs`.`PlaySessions`.`SessionID` AS `SessionID`,`nccs`.`PlaySessions`.`SessionName` AS `SessionName`,`nccs`.`PlaySessions`.`SessionType` AS `SessionType`,`nccs`.`PlaySessions`.`Priority` AS `Priority`,`nccs`.`PlaySessions`.`Status` AS `Status`,`nccs`.`PlaySessions`.`CircleLength` AS `CircleLength`,`nccs`.`PlaySessions`.`ClassID` AS `ClassID`,`nccs`.`PlaySessions`.`PlayerID` AS `PlayerID`,`nccs`.`PlaySessions`.`Parent` AS `Parent`,`nccs`.`PlayingSessions`.`PlayingFileID` AS `PlayingFileID`,`nccs`.`PlayingSessions`.`MultiPort` AS `MultiPort`,`nccs`.`PlayingSessions`.`CurrFileProgress` AS `CurrFileProgress`,`nccs`.`PlayingSessions`.`CurrTotalProgress` AS `CurrTotalProgress`,`nccs`.`PlayingSessions`.`Pause` AS `Pause`,`nccs`.`PlayingSessions`.`ScheduleID` AS `ScheduleID`,`nccs`.`PlaySessions`.`MemberMode` AS `MemberMode` from (`nccs`.`PlaySessions` left join `nccs`.`PlayingSessions` on((`nccs`.`PlayingSessions`.`SessionID` = `nccs`.`PlaySessions`.`SessionID`)));

-- -----------------------------------------------------
-- View `nccs`.`v_session_schedules`
-- -----------------------------------------------------
DROP VIEW IF EXISTS `nccs`.`v_session_schedules` ;
DROP TABLE IF EXISTS `nccs`.`v_session_schedules`;
USE `nccs`;
CREATE  OR REPLACE ALGORITHM=UNDEFINED DEFINER=`root`@`%` SQL SECURITY DEFINER VIEW `nccs`.`v_session_schedules` AS select `a`.`ScheduleID` AS `ScheduleID`,`a`.`TempFlag` AS `TempFlag`,`a`.`PlayTime` AS `PlayTime`,`a`.`WeekDay` AS `WeekDay`,`b`.`SessionID` AS `SessionID`,`b`.`SessionName` AS `SessionName`,`c`.`Pause` AS `Pause`,`b`.`BrdMode` AS `BrdMode`,`b`.`SessionType` AS `SessionType`,`b`.`SysEnabled` AS `SysEnabled`,`b`.`RfDevCtrl` AS `RfDevCtrl`,`b`.`StreamType` AS `StreamType` from ((`nccs`.`PlaySessionTime` `a` left join `nccs`.`PlaySessions` `b` on((`a`.`SessionID` = `b`.`SessionID`))) left join `nccs`.`PlayingSessions` `c` on((`a`.`ScheduleID` = `c`.`ScheduleID`)));

-- -----------------------------------------------------
-- View `nccs`.`v_stream_trans_table`
-- -----------------------------------------------------
DROP VIEW IF EXISTS `nccs`.`v_stream_trans_table` ;
DROP TABLE IF EXISTS `nccs`.`v_stream_trans_table`;
USE `nccs`;
CREATE  OR REPLACE ALGORITHM=UNDEFINED DEFINER=`root`@`%` SQL SECURITY DEFINER VIEW `nccs`.`v_stream_trans_table` AS select `a`.`NetworkID` AS `NetworkID`,`a`.`IpAddress` AS `proxy`,`b`.`IpAddress` AS `IpAddress`,`c`.`MultiPort` AS `MultiPort`,`c`.`SessionID` AS `SessionID` from ((`nccs`.`DeviceStatus` `a` left join `nccs`.`SubNetwork` `b` on((`b`.`idSubNetwork` = `a`.`NetworkID`))) left join `nccs`.`PlayingSessions` `c` on((`c`.`SessionID` = `a`.`ActualSessionID`))) where (`a`.`ActualSessionID` > 0) group by `c`.`SessionID`,`a`.`NetworkID`;

SET SQL_MODE=@OLD_SQL_MODE;
SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS;
SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS;
USE `nccs`;

DELIMITER $$

USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_brdmode_delete` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`localhost`
TRIGGER `nccs`.`tr_brdmode_delete`
BEFORE DELETE ON `nccs`.`BroadcastMode`
FOR EACH ROW
begin
     delete from PlaySessions  where BrdMode = old.idBroadcastMode;
     delete from BrdModeMember where BrdModeID = old.idBroadcastMode;
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_brdmode_update` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_brdmode_update`
AFTER UPDATE ON `nccs`.`BroadcastMode`
FOR EACH ROW
begin
                                  
    if  not (new.Priority = old.Priority) then
        update PlaySessions set Priority =  new.Priority where BrdMode = old.idBroadcastMode;
    end if;
    insert into Messages Values (0, 1, 2, 12, now(), null, new.idBroadcastMode, null, null);   
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_brdmode_update1` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_brdmode_update1`
BEFORE UPDATE ON `nccs`.`BroadcastMode`
FOR EACH ROW
begin
    if (new.Enabled = false) then
            set new.Active = false;
      end if;
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_devclasses_delete` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_devclasses_delete`
BEFORE DELETE ON `nccs`.`DevClasses`
FOR EACH ROW
begin
     delete from GroupCtrlSchedule where GroupID = old.ClassID;
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_devclasses_insert` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_devclasses_insert`
BEFORE INSERT ON `nccs`.`DevClasses`
FOR EACH ROW
begin
     declare count int default 0;
     declare parentid int default 0;
     
     set parentid = new.Parent;
     
     while (parentid is not null)  and (parentid <> 0) and (count < 5) do
      select Parent  into parentid from  DevClasses where ClassID = parentid;
      set count = count + 1;
     end while;
     
     if (count >= 5) then 
     insert DevClasses values(0,' ',0);
     end if;
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_devclasses_update` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`localhost`
TRIGGER `nccs`.`tr_devclasses_update`
AFTER UPDATE ON `nccs`.`DevClasses`
FOR EACH ROW
begin
     declare count int default 0;
     declare parentid int default 0;
     
     set parentid = new.Parent;
     
     while (parentid is not null)  and (parentid <> 0) and (count < 5) do
      select Parent  into parentid from  DevClasses where ClassID = parentid;
      set count = count + 1;
     end while;
     
     if (count >= 5) then 
     insert DevClasses values(0,' ',0);
     end if;
     
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_devicelist_delete` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_devicelist_delete`
BEFORE DELETE ON `nccs`.`DeviceList`
FOR EACH ROW
begin
     delete from DevCtrlSchedule where DevID = old.DevID;
     delete from DeviceDesiredStaus where DeviceID =  old.DevID;
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`DeviceList_AUPD` $$
USE `nccs`$$
CREATE TRIGGER `DeviceList_AUPD` 
AFTER UPDATE ON `DeviceList` FOR EACH ROW

begin
    insert into Messages Values (0, 1, 2, 3, now(), 0, 0, new.DevID, NULL);  
end
$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_DeviceDesiredStaus_update` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_DeviceDesiredStaus_update`
BEFORE UPDATE ON `nccs`.`DeviceDesiredStaus`
FOR EACH ROW
begin
    if  (new. BrdMode is null and old.BrdMode is not null) or
         (new. BrdMode is not null and old.BrdMode is null) or
         (new. BrdMode != old.BrdMode) or 
         (new. ModePriority != old.ModePriority) then
        set new.SessionValid = false;
     end if;   
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_dev_changed1` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_dev_changed1`
AFTER UPDATE ON `nccs`.`DeviceStatus`
FOR EACH ROW
begin
    declare ctrl_user_id int default null;
	insert into Messages Values (0, 1, 2, 3, now(), 0, 0, new.DeviceID, NULL);  
    
     if (old.State_SysPower <> new.State_SysPower) then
         if (new.State_SysPower = 2) then
              -- device is disalbed
             insert into DeviceLog(`DeviceID`, `DateTime`, `Event`, `State`)  Values (new.DeviceID, now(), 3, 0);  
          else
             if (old.State_SysPower = 2) then
                  -- device is enabled
                 insert into DeviceLog(`DeviceID`, `DateTime`, `Event`, `State`)  Values (new.DeviceID, now(), 3, 1);
             else
				 select UserID into ctrl_user_id from TempIcCard where new.DeviceID = TempIcCard.DeviceID limit 1;
                 insert into DeviceLog(`DeviceID`, `DateTime`, `Event`, `State`, `CtrlUser`)  
			         Values (new.DeviceID, now(), 2, new.State_SysPower , ctrl_user_id);
                  --   insert into DeviceLog(`DeviceID`, `DateTime`, `Event`, `State`)  Values (new.DeviceID, now(), 2, new.State_SysPower);  
             end if;    
         end if;         
      end if;
      
      if (old.State_ProjectorLampStatus <> new.State_ProjectorLampStatus) then
          insert into DeviceLog(`DeviceID`, `DateTime`, `Event`, `State`)  Values (new.DeviceID, now(), 4, new.State_ProjectorLampStatus);  
      end if;
      
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_dev_del` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_dev_del`
AFTER DELETE ON `nccs`.`DeviceStatus`
FOR EACH ROW
begin
     -- delete from tmp_devcice_session  where tmp_devcice_session.DeviceID = old.DeviceID;
     update DeviceDesiredStaus set SessionValid = false where DeviceDesiredStaus.DeviceID = old.DeviceID;
     INSERT INTO Messages Values (0, 1, 2, 3, now(), 0, 0, old.DeviceID, NULL);
     
     insert into DeviceLog(`DeviceID`, `DateTime`, `Event`, `State`)  Values (old.DeviceID, now(), 1, 0);  
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_dev_instert` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_dev_instert`
AFTER INSERT ON `nccs`.`DeviceStatus`
FOR EACH ROW
begin
     -- INSERT INTO Messages Values(0, 1, 1, 1, now(), 55, 0, new.DeviceID, new.IpAddress);     
     -- get config for inserting
     call sp_send_dev_ctrl_cmd(new.DeviceID, new.IpAddress, 55, 0, 0, 0, null);
     
     insert into DeviceLog(`DeviceID`, `DateTime`, `Event`, `State`)  Values (new.DeviceID, now(), 1, 1);  
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_player_delete` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_player_delete`
BEFORE DELETE ON `nccs`.`Players`
FOR EACH ROW
begin
-- delete from PlaySessionGroups where PlayerID = old.PlayerID;
-- delete from PlayGroups where PlayerID = old.PlayerID;
delete from PlayerKeys where PlayerID = old.PlayerID;
-- delete from PlayGroupDevices where PlayerID = old.PlayerID;
delete from PlaySessions where PlayerID = old.PlayerID;
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_player_insert` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_player_insert`
AFTER INSERT ON `nccs`.`Players`
FOR EACH ROW
begin
if ((new.PlayerType <> 0) and (new.PlayerType <> 8)) then
	insert into   PlaySessions(SessionID, SessionType, PlayerID, Priority, SessionName) 
              values (get_idle_sessionid(false), new.PlayerType, new.PlayerID, new.Priority, new.PlayerID) ;           
  end if;  
  end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_user_delete` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_user_delete`
BEFORE DELETE ON `nccs`.`Users`
FOR EACH ROW
begin
	declare tmp_mediaid int default 0;

	select MediaID into tmp_mediaid from MediaFiles where `Owner` = Old.User_ID and Sysfolder = 1;
	if((tmp_mediaid is not null) and tmp_mediaid <> 0) then
		set max_sp_recursion_depth=10;
		call sp_del_media_file(Old.User_ID,tmp_mediaid); 
	end if;

        delete from UserDevices where UserID = old.User_ID;
        -- delete from Players where PlayerID = old.UsbKey;
		delete PlaySessionTime from PlaySessionTime, PlaySessions  
               where PlaySessions.Owner = old.User_ID and PlaySessionTime. SessionID = PlaySessions.SessionID;
	delete from PlaySessions where Owner = old.User_ID;
	delete from MediaFiles where Owner = Old.User_ID;
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_user_insert` $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` TRIGGER `nccs`.`tr_user_insert`
AFTER INSERT ON `nccs`.`Users`
FOR EACH ROW
begin
	declare tmp_mediaid int default 0;

    if (new.UsbKey is not null) then 
        /*after player insterted, a session will be created*/
        -- insert into Players(PlayerID, PlayerType, Priority ) values (new.UsbKey, 2, new.Priority) ;
		update PlaySessions set Owner = new.User_ID, SessionType = 1 where (PlaySessions.PlayerID = new.UsbKey);
    end if;

	if ((new.privilege & 0x100) <> 0 and (new.User_Name is not null))  then 
        -- have Broadcast privilege 
		
		select MediaID into tmp_mediaid from MediaFiles where Sysfolder=2;

		if((tmp_mediaid is not null) and tmp_mediaid <> 0) then
			insert into MediaFiles(FileName,FileSize,TotalTime,FileFmt,BitRate,VedioCodec,
				Height,Width,FrameRate,AudioCodec,Channels,SampleRate,Gain,CreateTime,Parent,`Owner`,Sysfolder) values(
				new.User_Desc,0,0,0,0,0,0,0,0,0,0,0,0,now(),tmp_mediaid,new.User_ID,1);
		else
			insert into MediaFiles(FileName,FileSize,TotalTime,FileFmt,BitRate,VedioCodec,
				Height,Width,FrameRate,AudioCodec,Channels,SampleRate,Gain,CreateTime,Sysfolder) values(
				'用户文件',0,0,0,0,0,0,0,0,0,0,0,0,now(),2);

			select MediaID into tmp_mediaid from MediaFiles where Sysfolder=2;

			insert into MediaFiles(FileName,FileSize,TotalTime,FileFmt,BitRate,VedioCodec,
				Height,Width,FrameRate,AudioCodec,Channels,SampleRate,Gain,CreateTime,Parent,`Owner`,Sysfolder) values(
				new.User_Desc,0,0,0,0,0,0,0,0,0,0,0,0,now(),tmp_mediaid,new.User_ID,1);
		end if;
		
	end if;

end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_user_insert_player` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_user_insert_player`
BEFORE INSERT ON `nccs`.`Users`
FOR EACH ROW
begin
    if (new.UsbKey is not null) then 
        /*after player insterted, a session will be created*/
        insert into Players(PlayerID, PlayerType, Priority ) values (new.UsbKey, 2, new.Priority) ;
    end if;
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_user_update` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_user_update`
AFTER UPDATE ON `nccs`.`Users`
FOR EACH ROW
begin
	declare tmp_root_mediaid int default 0;
	declare tmp_mediaid int default 0;

    if ((new.UsbKey is not null) and (old.UsbKey is null)) or
       ((old.UsbKey is not null) and (new.UsbKey is null)) or 
       (old.UsbKey <> new.UsbKey) then 
        delete from Players where PlayerID = old.UsbKey;

       /*after player insterted, a session will be created*/
        if (new.UsbKey is not null) then 
            -- insert into Players(PlayerID, PlayerType, Priority ) values (new.UsbKey, 2, new.Priority);
			update PlaySessions set Owner = new.User_ID, SessionType = 1 where (PlaySessions.PlayerID = new.UsbKey);
        end if;

    end if;

    if (new.Priority <> old.Priority) then
        update PlaySessions set  Priority = new.Priority 
               where PlaySessions.Owner = new.User_ID;
    end if;

	if ((new.privilege & 0x01) = 0) then 
        -- Device control privilege has been removed
		delete PlaySessionTime from PlaySessionTime, PlaySessions  
               where PlaySessions.Owner = old.User_ID and 
					 PlaySessionTime. SessionID = PlaySessions.SessionID and 
                     (SysEnabled is not null);
    end if;

	if ((new.privilege & 0x100) = 0)  then 
        -- Broadcast privilege has been removed
        delete PlaySessionTime from PlaySessionTime, PlaySessions  
               where PlaySessions.Owner = old.User_ID and 
					 PlaySessionTime. SessionID = PlaySessions.SessionID and 
                     (PlaySessions.StreamType <> 0);

		-- del MediaFiles user root folder
		select MediaID into tmp_mediaid from MediaFiles where `Owner` = new.User_ID and Sysfolder = 1;
		if((tmp_mediaid is not null) and tmp_mediaid <> 0) then
			set max_sp_recursion_depth=10;
			call sp_del_media_file(new.User_ID,tmp_mediaid); 
		end if;
	else
		-- have Broadcast privilege
		select MediaID into tmp_root_mediaid from MediaFiles where Sysfolder = 2;

		if((tmp_root_mediaid is not null) and tmp_root_mediaid <> 0) then

			select MediaID into tmp_mediaid from MediaFiles where `Owner` = new.User_ID and Sysfolder = 1;
			
			if((tmp_mediaid is not null) and tmp_mediaid <> 0) then
				if(new.User_Desc <> Old.User_Desc) then
					update MediaFiles set FileName=new.User_Desc where MediaID = tmp_mediaid;
				end if;
			else
				insert into MediaFiles(FileName,FileSize,TotalTime,FileFmt,BitRate,VedioCodec,
					Height,Width,FrameRate,AudioCodec,Channels,SampleRate,Gain,CreateTime,Parent,`Owner`,Sysfolder) values(
					new.User_Desc,0,0,0,0,0,0,0,0,0,0,0,0,now(),tmp_root_mediaid,new.User_ID,1);
			end if;
			
		else
			insert into MediaFiles(FileName,FileSize,TotalTime,FileFmt,BitRate,VedioCodec,
				Height,Width,FrameRate,AudioCodec,Channels,SampleRate,Gain,CreateTime,Sysfolder) values(
				'用户文件',0,0,0,0,0,0,0,0,0,0,0,0,now(),2);

			select MediaID into tmp_root_mediaid from MediaFiles where Sysfolder = 2;

			insert into MediaFiles(FileName,FileSize,TotalTime,FileFmt,BitRate,VedioCodec,
				Height,Width,FrameRate,AudioCodec,Channels,SampleRate,Gain,CreateTime,Parent,`Owner`,Sysfolder) values(
				new.User_Desc,0,0,0,0,0,0,0,0,0,0,0,0,now(),tmp_root_mediaid,new.User_ID,1);
		end if;

    end if;

	if ((new.privilege & 0x10000) = 0)  then 
        -- wireless device control privilege has been removed
        delete PlaySessionTime from PlaySessionTime, PlaySessions  
               where PlaySessions.Owner = old.User_ID and 
					 PlaySessionTime. SessionID = PlaySessions.SessionID and 
                     (RfDevCtrl is not null);
    end if;

end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_user_update_player` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_user_update_player`
BEFORE UPDATE ON `nccs`.`Users`
FOR EACH ROW
begin
    if ((new.UsbKey is not null) and (old.UsbKey is null)) or
       (old.UsbKey <> new.UsbKey) then 
	    insert into Players(PlayerID, PlayerType, Priority ) values (new.UsbKey, 2, new.Priority);
    end if;
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_user_delete_player` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_user_delete_player`
AFTER DELETE ON `nccs`.`Users`
FOR EACH ROW
begin
    delete from Players where PlayerID = old.UsbKey;
end
$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_session_delete` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`localhost`
TRIGGER `nccs`.`tr_session_delete`
BEFORE DELETE ON `nccs`.`PlaySessions`
FOR EACH ROW
begin
	 -- stop all sessions while the stoped task is playing
	 update PlayerStatus set SessionID = 0 where (SessionID = old.SessionID);
     -- delete from PlaySessionTime  where SessionID = old.SessionID;
     delete from PlayListFiles where SessionID = old.SessionID;
     delete from SessionDevice where SessionID = old.SessionID;
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_session_insert` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_session_insert`
BEFORE INSERT ON `nccs`.`PlaySessions`
FOR EACH ROW
begin
     declare count int default 0;
     declare parentid int default 0;
     declare Sestype int default 0;
     
     set parentid = new.Parent;
     
     /*
        check loop
        To make ensure the tree is not loopped.
     */
     while (parentid is not null)  and (parentid <> 0) and (count < 5) do
      select Parent , SessionType into parentid, Sestype from  PlaySessions where SessionID = parentid;
      if (Sestype = 127) then
            set count = count + 1;
        else
           set count =  5;
         end if;
         
     end while;
     
     if (count >= 5) then 
     insert PlaySessions(SessionID) values(0);
     end if;
    
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_session_update` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`localhost`
TRIGGER `nccs`.`tr_session_update`
AFTER UPDATE ON `nccs`.`PlaySessions`
FOR EACH ROW
begin
     declare count int default 0;
     declare parentid int default 0;
     declare Sestype int default 0;
     
     set parentid = new.Parent;
     
     while (parentid is not null)  and (parentid <> 0) and (count < 5) do
        select Parent , SessionType into parentid, Sestype from  PlaySessions where SessionID = parentid;
         if (Sestype = 127) then
            set count = count + 1;
        else
           set count =  5;
         end if;
     end while;
     
     if (count >= 5) then 
         insert PlaySessions(SessionID) values(0);
     end if;
     
     if (new.Priority <> old.Priority) then
         update DeviceDesiredStaus, SessionDevice set  DeviceDesiredStaus.SessionValid = false 
                 where DeviceDesiredStaus.DeviceID = SessionDevice.DeviceID and
                                SessionDevice.SessionID = new.SessionID;
                                
          update DeviceDesiredStaus, PlayerKeys set  DeviceDesiredStaus.SessionValid = false 
                 where PlayerKeys.PlayerID = new.PlayerID and 
                                PlayerKeys.GroupDisable = 0 and
                                PlayerKeys.GroupID is not null and 
                                sp_dev_belong_group(DeviceDesiredStaus. DeviceID, PlayerKeys.GroupID);
     end if;
     
     if (new.MemberMode <> old.MemberMode) then
         if (new.MemberMode = true) then
             delete from SessionDevice where SessionID = new.SessionID;
          end if; 
      
          if (new.BrdMode <> 0) then
               update DeviceDesiredStaus, BrdModeMember set  DeviceDesiredStaus.SessionValid = false 
                   where DeviceDesiredStaus.DeviceID =  BrdModeMember.DeviceID and
                                 BrdModeMember.BrdModeID <> new.BrdMode;
          end if;
      end if;
      
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_play_Schedule_delete` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_play_Schedule_delete`
BEFORE DELETE ON `nccs`.`PlaySessionTime`
FOR EACH ROW
begin
 INSERT INTO Messages Values (0, 1, 2, 10, now(), 0, old.ScheduleID, null, null);
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_play_Schedule_update` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_play_Schedule_update`
AFTER UPDATE ON `nccs`.`PlaySessionTime`
FOR EACH ROW
begin
 INSERT INTO Messages Values (0, 1, 2, 10, now(), 0, new.ScheduleID, null, null);
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_media_insert` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_media_insert`
BEFORE INSERT ON `nccs`.`MediaFiles`
FOR EACH ROW
begin
     declare count int default 0;
     declare parentid int default 0;
     declare nodetype int default 0;
     declare last_id int default null;

     set parentid = new.Parent;
     
     while (parentid is not null)  and (parentid <> 0) and (count < 5) do
      select Parent , TotalTime into parentid, nodetype from  MediaFiles where MediaID = parentid;
      if ((nodetype = 0)  or (nodetype is null)) then
            set count = count + 1;
        else
           set count =  5;
         end if;
         
     end while;
     
     if ((count >= 5) or (count = 4 and new.TotalTime = 0)) then 
     insert MediaFiles(MediaID) values(0);
     end if;
	
	select InfoValue into  last_id from BaseInfo where InfomationID=0x100;
    if last_id is not null then 
        set new.MediaID = last_id + 1;
	end if;

end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_media_update` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`localhost`
TRIGGER `nccs`.`tr_media_update`
AFTER UPDATE ON `nccs`.`MediaFiles`
FOR EACH ROW
begin
     declare count int default 0;
     declare parentid int default 0;
     declare nodetype int default 0;
     
     set parentid = new.Parent;
     
     while (parentid is not null)  and (parentid <> 0) and (count < 5) do
        select Parent , TotalTime into parentid, nodetype from  MediaFiles where MediaID = parentid;
        if ((nodetype = 0)  or (nodetype is null)) then
            set count = count + 1;
        else
           set count =  5;
         end if;
     end while;
     
     if (count >= 5) then 
     insert MediaFiles(MediaID) values(0);
     end if;
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_media_insert1` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_media_insert1`
AFTER INSERT ON `nccs`.`MediaFiles`
FOR EACH ROW
begin
	insert into BaseInfo(InfomationID, InfoValue) values(0x100, new.MediaID) on duplicate key update InfoValue=values(InfoValue);
end
$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_media_after_delete` $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` TRIGGER `tr_media_after_delete` AFTER DELETE ON `MediaFiles` FOR EACH ROW
begin
	if(Old.TotalTime <> 0 and Old.FileFmt <> -1) then
		insert into tmp_DelMediaFiles(filepath) values(Old.FilePath);
	end if;
end
$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`bef_media_delete` $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` TRIGGER `bef_media_delete` BEFORE DELETE ON `MediaFiles` FOR EACH ROW
begin
	if(Old.Sysfolder = 2) then
		-- not allow delete
		insert MediaFiles(MediaID) values(0);
	end if;
end;
$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`bef_media_update` $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` TRIGGER `bef_media_update` BEFORE UPDATE ON `MediaFiles` FOR EACH ROW
begin
	declare tmp_root_mediaid int default 0;

	if(new.Sysfolder = 2 ) then
		-- not allow update
		insert MediaFiles(MediaID) values(0);
	end if;

	select MediaID into tmp_root_mediaid from MediaFiles where Sysfolder = 2 limit 1;
	if((tmp_root_mediaid is not null) and tmp_root_mediaid <> 0) then
		-- not allow move to Sysfolder = 2
		if((new.Parent = tmp_root_mediaid) and (new.Sysfolder is null or new.Sysfolder <> 1)) then			
			insert MediaFiles(MediaID) values(0);
		end if;

		-- not allow move to Sysfolder = 1
		if((new.Sysfolder = 1) and (new.Parent <> tmp_root_mediaid)) then			
			insert MediaFiles(MediaID) values(0);
		end if;

	end if;
end;
$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_PlayerKeys_update` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_PlayerKeys_update`
AFTER UPDATE ON `nccs`.`PlayerKeys`
FOR EACH ROW
begin                               
     update DeviceDesiredStaus set  DeviceDesiredStaus.SessionValid = false 
                 where old.GroupID is not null and sp_dev_belong_group(DeviceDesiredStaus. DeviceID, old.GroupID);  
                 
    if not (new.GroupID = old.GroupID) then
           update DeviceDesiredStaus set  DeviceDesiredStaus.SessionValid = false 
                 where new.GroupID is not null  and sp_dev_belong_group(DeviceDesiredStaus. DeviceID, new.GroupID);
     end if;            
    
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_playerstatus_delete` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_playerstatus_delete`
BEFORE DELETE ON `nccs`.`PlayerStatus`
FOR EACH ROW
begin
    delete from PlayingSessions where SessionID = old.SessionID;   
    
    insert into Messages Values (0, 1, 2, 3, now(), 0, 0, old.PlayerID, NULL);
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_playerstatus_insert` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_playerstatus_insert`
AFTER INSERT ON `nccs`.`PlayerStatus`
FOR EACH ROW
begin    
    insert into Messages Values (0, 1, 2, 3, now(), 0, 0, new.PlayerID, NULL);
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_playerstatus_update` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_playerstatus_update`
BEFORE UPDATE ON `nccs`.`PlayerStatus`
FOR EACH ROW
begin

if (new.SessionID is null) or (new.SessionID  = 0) then
    delete from PlayingSessions where SessionID = old.SessionID;
    
    -- not send device command for automatic media player
     if ((new.PlayType <> 0) and (new.PlayType <> 8) and (new.ActualSesID <> 0))  then
                call sp_send_dev_ctrl_cmd(new.PlayerID, new.IpAddress, 133, new.ActualSesID, 0, 0, null);
                set  new.ActualSesID = 0; 
    end if ;
 else
     insert into PlayingSessions(SessionID, PlayerID, Priority, MultiPort, CircleLength, ScheduleID, BrdMode, SesType, StreamType)
            select  a.SessionID, b.PlayerID, a.Priority, new.PlayPort, a.CircleLength, new.ScheduleID, a.BrdMode, a.SessionType, a.StreamType 
                           from PlaySessions a, Players b
                           where b.PlayerID = new.PlayerID and a.SessionID = new.SessionID
            on duplicate key update PlayerID = values(PlayerID) , Priority = values(Priority) , 
                         MultiPort = values(MultiPort) , CircleLength = values(CircleLength) ,
                         ScheduleID = values(ScheduleID) , BrdMode = values(BrdMode),
                         SesType = values(SesType), StreamType = values(StreamType);
            
     if (not new.SessionID = new.ActualSesID)  and (new.PlayType <> 0) and (new.PlayType <> 8)  then
            call sp_send_dev_ctrl_cmd(new.PlayerID, new.IpAddress, 131, new.SessionID, 
                                                                      8064, get_srv_ip(), null);
             set new.ActualSesID =  new.SessionID;            
     end if;         
end if;    
 
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_playerstatus_update_a` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_playerstatus_update_a`
AFTER UPDATE ON `nccs`.`PlayerStatus`
FOR EACH ROW
begin    
    insert into Messages Values (0, 1, 2, 3, now(), 0, 0, new.PlayerID, NULL);
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_playing_ses_del` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_playing_ses_del`
AFTER DELETE ON `nccs`.`PlayingSessions`
FOR EACH ROW
begin
     INSERT INTO Messages Values (0, 1, 2, 10, now(), old.SessionID, old.ScheduleID, null, null);
     delete from PlaySessionTime where PlaySessionTime.ScheduleID = old.ScheduleID and TempFlag = 1;
     
    update DeviceDesiredStaus set  DeviceDesiredStaus.SessionValid = false 
           where  DeviceDesiredStaus.SessionID = old.SessionID;
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_playing_ses_ins` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_playing_ses_ins`
AFTER INSERT ON `nccs`.`PlayingSessions`
FOR EACH ROW
begin
     INSERT INTO Messages Values (0, 1, 2, 10, now(), new.SessionID, new.ScheduleID, null, null);
     
     if (new.BrdMode > 0) then
          update DeviceDesiredStaus set  DeviceDesiredStaus.SessionValid = false  where DeviceDesiredStaus.BrdMode = new.BrdMode;
      end if;

      update DeviceDesiredStaus, SessionDevice set  DeviceDesiredStaus.SessionValid = false 
                 where DeviceDesiredStaus.DeviceID = SessionDevice.DeviceID and
                                SessionDevice.SessionID = new.SessionID;
      
      update DeviceDesiredStaus, PlayerKeys set  DeviceDesiredStaus.SessionValid = false 
                 where PlayerKeys.PlayerID = new.PlayerID and 
                                PlayerKeys.GroupDisable = 0 and
                                PlayerKeys.GroupID is not null and 
                                sp_dev_belong_group(DeviceDesiredStaus. DeviceID, PlayerKeys.GroupID);
                                
    
                 
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_playing_ses_update` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_playing_ses_update`
AFTER UPDATE ON `nccs`.`PlayingSessions`
FOR EACH ROW
begin
    if (new.Pause <> old.Pause) then
     INSERT INTO Messages Values (0, 1, 2, 10, now(), new.SessionID, new.ScheduleID, null, null);
     end if;
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_ses_dev_ses_del` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_ses_dev_ses_del`
AFTER DELETE ON `nccs`.`SessionDevice`
FOR EACH ROW
begin 
    update DeviceDesiredStaus set  DeviceDesiredStaus.SessionValid = false  
               where  DeviceDesiredStaus.DeviceID = old.DeviceID and 
                              DeviceDesiredStaus.SessionID = old.SessionID;
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_ses_dev_ses_ins` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_ses_dev_ses_ins`
AFTER INSERT ON `nccs`.`SessionDevice`
FOR EACH ROW
begin 
    update DeviceDesiredStaus set  DeviceDesiredStaus.SessionValid = false  where  DeviceDesiredStaus.DeviceID = new.DeviceID;
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_ses_dev_ses_update` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_ses_dev_ses_update`
AFTER UPDATE ON `nccs`.`SessionDevice`
FOR EACH ROW
begin 
    update DeviceDesiredStaus set  DeviceDesiredStaus.SessionValid = false  
              where  DeviceDesiredStaus.DeviceID = new.DeviceID;
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_userdev_delete` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_userdev_delete`
BEFORE DELETE ON `nccs`.`UserDevices`
FOR EACH ROW
begin
        delete SessionDevice from SessionDevice, PlaySessions 
                        where PlaySessions.Owner = old.UserID and
                              SessionDevice.SessionID =  PlaySessions.SessionID and  
							  SessionDevice.DeviceID = old.DevID;
       
end$$


DELIMITER ;
